@@ -15,8 +15,9 @@ import Tagify from './vendors/tagify/tagify.min.js'
 
 import './vendors/datatables/datatable-ipsorting'
 import './vendors/datatables/datatable-macsorting'
-import './vendors/datatables/datatables-colreorder'
 import './vendors/datatables/datatable-colvisibility'
 
+import './vendors/dygraphs/canvas';
+
 window.nv = nv
 window.Tagify = Tagify
