@@ -31,11 +31,12 @@ class AddressResolution {
   Mutex m;
 
  public:
-  AddressResolution();
+  AddressResolution(int num_resolvers);
   ~AddressResolution();
 
   void startResolveAddressLoop();
-  void resolveHostName(const char *numeric_ip, char *rsp = NULL, u_int rsp_len = 0);
+  void resolveHostName(const char *numeric_ip, char *rsp = NULL,
+                       u_int rsp_len = 0);
   bool resolveHost(const char *host, char *rsp, u_int rsp_len, bool v4);
 };
 
