@@ -25,12 +25,15 @@
 #include "ntop_includes.h"
 
 class Bitmap128 {
-private:
+ private:
   u_int64_t bitmap[2];
 
-public:
+ public:
   Bitmap128() { reset(); }
-  Bitmap128(char *list) { reset(); setBits(list); };
+  Bitmap128(char *list) {
+    reset();
+    setBits(list);
+  };
 
   static inline u_int numBits() { return sizeof(bitmap) * 8; };
   void reset();
@@ -41,9 +44,9 @@ public:
   void bitmapOr(const Bitmap128 b);
   void set(const Bitmap128 *b);
   bool equal(const Bitmap128 *b) const;
-  
-  void lua(lua_State* vm, const char *label) const;
-  const char * toHexString(char *buf, ssize_t buf_len) const;
+
+  void lua(lua_State *vm, const char *label) const;
+  const char *toHexString(char *buf, ssize_t buf_len) const;
 };
 
 #endif /* _BITMAP128_H_ */
