@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-22 - ntop.org
+ * (C) 2019-23 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,21 +22,23 @@
 #ifndef _BLACKLIST_STATS_H_
 #define _BLACKLIST_STATS_H_
 
-
 class BlacklistStats {
  private:
+  RwLock lock;
   std::unordered_map<std::string, BlacklistUsageStats> stats;
 
  public:
   BlacklistStats() { ; }
 
 #ifdef FULL_BL_STATS
-  void inc(std::string name, u_int32_t tp, u_int32_t fp, u_int32_t fn, u_int32_t tn);
+  void inc(std::string name, u_int32_t tp, u_int32_t fp, u_int32_t fn,
+           u_int32_t tn);
 #endif
 
-  void      incHits(std::string name);
+  void incHits(std::string name);
   u_int32_t getNumHits(std::string name);
-  void      lua(lua_State* vm);
+  void reset();
+  void lua(lua_State* vm);
 };
 
 #endif /* _BLACKLIST_STATS_H_ */
