@@ -27,31 +27,33 @@
 class ElasticSearch : public DB {
  private:
   pthread_t esThreadLoop;
-  u_int num_queued_elems;
-  struct string_list *head, *tail;
-  Mutex listMutex;
+  std::atomic<u_int32_t> num_queued_elems;
+  SPSCQueue<char *> *export_queue;
+
   bool reportDrops;
+  time_t lastReportedDropsTime;
+
   char *es_template_push_url, *es_version_query_url;
   char es_version[2];
   bool es_version_inited;
 
-  const char * get_es_version();
-  const char * get_es_template();
+  const char *get_es_version();
+  const char *get_es_template();
   void shutdown();
-  
+
  public:
   ElasticSearch(NetworkInterface *_iface);
   ~ElasticSearch();
 
   inline bool atleast_version_6() {
-    const char * ver = get_es_version();
-    
+    const char *ver = get_es_version();
+
     return ver && strcmp(ver, "6") >= 0;
   };
 
   inline bool atleast_version_8() {
-    const char * ver = get_es_version();
-    
+    const char *ver = get_es_version();
+
     return ver && strcmp(ver, "8") >= 0;
   };
 
@@ -62,5 +64,4 @@ class ElasticSearch : public DB {
   virtual bool startQueryLoop();
 };
 
-
 #endif /* _ELASTIC_SEARCH_H_ */
