@@ -29,9 +29,10 @@ class Flow;
 class FlowChecksExecutor { /* One instance per ntopng Interface */
  private:
   NetworkInterface *iface;
-  std::list<FlowCheck*> *protocol_detected, *periodic_update, *flow_end, *flow_begin;
+  std::list<FlowCheck *> *protocol_detected, *periodic_update, *flow_end,
+      *flow_begin;
 
-  void loadFlowChecksAlerts(std::list<FlowCheck*> *cb_list);
+  void loadFlowChecksAlerts(std::list<FlowCheck *> *cb_list);
   void loadFlowChecks(FlowChecksLoader *fcl);
 
  public:
