@@ -29,18 +29,19 @@ class FlowRiskAlerts {
 
  public:
   static inline u_int8_t getFlowRiskScore(ndpi_risk_enum risk) {
-    if(risk < NDPI_MAX_RISK) {
-      ndpi_risk r = 0; u_int16_t c, s;
-      
+    if (risk < NDPI_MAX_RISK) {
+      ndpi_risk r = 0;
+      u_int16_t c, s;
+
       ndpi_risk2score(NDPI_SET_BIT(r, risk), &c, &s);
 
-      return(c + s);
-    } 
-    return(0);
+      return (c + s);
+    }
+    return (0);
   }
-  
-  static FlowAlertType getFlowRiskAlertType(ndpi_risk_enum risk);  
-  static const char * getCheckName(ndpi_risk_enum risk);
+
+  static FlowAlertType getFlowRiskAlertType(ndpi_risk_enum risk);
+  static const char* getCheckName(ndpi_risk_enum risk);
   static void checkUndefinedRisks();
   static bool lua(lua_State* vm);
 };
