@@ -33,20 +33,21 @@ class HTTPserver {
   char *docs_dir, *scripts_dir;
   struct mg_context *httpd_v4;
   bool ssl_enabled, gui_access_restricted;
-  char *captive_redirect_addr;
   char *wispr_captive_data;
   bool check_ssl_cert(char *ssl_cert_path, size_t ssl_cert_path_len);
-  char ports[256], acl_management[256], ssl_cert_path[2*MAX_PATH], access_log_path[2*MAX_PATH];
+  char ports[256], acl_management[256], ssl_cert_path[2 * MAX_PATH],
+      access_log_path[2 * MAX_PATH];
   const char *http_binding_addr1, *http_binding_addr2;
   const char *https_binding_addr1, *https_binding_addr2;
   const char *http_options[32];
   int cur_http_options;
 
-  void addHTTPOption(const char *k, const char*v);
+  void addHTTPOption(const char *k, const char *v);
   void startHttpServer();
-  
-  static void parseACL(char * const acl, u_int acl_len);
+
+  static void parseACL(char *const acl, u_int acl_len);
 #ifdef HAVE_NEDGE
+  char *captive_redirect_addr;
   struct mg_context *httpd_captive_v4;
 #endif
 
@@ -58,38 +59,46 @@ class HTTPserver {
   static bool authorized_localhost_user_login(const struct mg_connection *conn);
   static void traceLogin(const char *user, bool authorized);
 
-  bool authorize_noconn(char *username, char *session_id, u_int session_id_size, u_int session_duration);
+  bool authorize_noconn(char *username, char *session_id, u_int session_id_size,
+                        u_int session_duration);
   /*
     Creates an REST API token for user identified with `username`
    */
-  bool create_api_token(const char *username, char *api_token, u_int api_token_size);
+  bool create_api_token(const char *username, char *api_token,
+                        u_int api_token_size);
 
-  inline char*     get_docs_dir()    { return(docs_dir);         };
-  inline char*     get_scripts_dir() { return(scripts_dir);      };
-  inline bool      is_ssl_enabled()  { return(ssl_enabled);      };
-  inline bool      is_gui_access_restricted() { return(gui_access_restricted); };
-  inline void      start_accepting_requests() { can_accept_requests = true; };
+  inline char *get_docs_dir() { return (docs_dir); };
+  inline char *get_scripts_dir() { return (scripts_dir); };
+  inline bool is_ssl_enabled() { return (ssl_enabled); };
+  inline bool is_gui_access_restricted() { return (gui_access_restricted); };
+  inline void start_accepting_requests() { can_accept_requests = true; };
   bool accepts_requests();
 
-  inline const char* getWisprCaptiveData() { return(wispr_captive_data ? wispr_captive_data : ""); }
-  inline const char* getCaptiveRedirectAddress() { return(captive_redirect_addr ? captive_redirect_addr : ""); }
-  void setCaptiveRedirectAddress(const char*addr);
-
 #ifdef HAVE_NEDGE
+  void addCaptiveRedirectAddress(const char *addr);
+  inline const char *getCaptiveRedirectAddress() {
+    return (captive_redirect_addr ? captive_redirect_addr : "");
+  }
+  const char *getCaptiveLoginAddress(char *buf, int buf_size, const char *ip,
+                                     bool *custom_url);
+  const char *getWisprCaptiveData(char *buf, int buf_size, const char *addr);
   void startCaptiveServer();
   void stopCaptiveServer();
 #endif
 };
 
-extern int send_error(struct mg_connection *conn, int status, const char *reason, const char *fmt, ...);
+extern int send_error(struct mg_connection *conn, int status,
+                      const char *reason, const char *fmt, ...);
 extern int redirect_to_error_page(struct mg_connection *conn,
-				  const struct mg_request_info *request_info,
-				  const char *i18n_message,
-				  char *script_path, char *error_message);
+                                  const struct mg_request_info *request_info,
+                                  const char *i18n_message, char *script_path,
+                                  char *error_message);
 
-const char *get_secure_cookie_attributes(const struct mg_request_info *request_info);
+const char *get_secure_cookie_attributes(
+    const struct mg_request_info *request_info);
 
 /* mongoose */
-extern int url_decode(const char *src, int src_len, char *dst, int dst_len, int is_form_url_encoded);
+extern int url_decode(const char *src, int src_len, char *dst, int dst_len,
+                      int is_form_url_encoded);
 
 #endif /* _HTTP_SERVER_H_ */
