@@ -30,21 +30,22 @@ class ParserInterface : public NetworkInterface {
   u_int8_t num_companion_interfaces;
   NetworkInterface **companion_interfaces;
 
-  static bool isProbingFlow(const ParsedFlow * zflow);
+  static bool isProbingFlow(const ParsedFlow *zflow);
   virtual void reloadCompanions();
 
  public:
-  ParserInterface(const char *endpoint, const char *custom_interface_type = NULL);
+  ParserInterface(const char *endpoint,
+                  const char *custom_interface_type = NULL);
   ~ParserInterface();
 
-  virtual bool is_ndpi_enabled() const    { return(false);      };
-  virtual u_int getPacketOverhead() { return 0; /* Can't determine this for non-packet interfaces */ }
+  virtual bool is_ndpi_enabled() const { return (false); };
+  virtual u_int getPacketOverhead() {
+    return 0; /* Can't determine this for non-packet interfaces */
+  }
   bool processFlow(ParsedFlow *zflow);
 
-  void deliverFlowToCompanions(ParsedFlow * const flow);
+  void deliverFlowToCompanions(ParsedFlow *const flow);
   inline bool companionsEnabled() { return num_companion_interfaces > 0; };
 };
 
 #endif /* _PARSER_INTERFACE_H_ */
-
-
