@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2017-18 - ntop.org
+ * (C) 2017-23 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,36 +29,51 @@ class QueuedThreadData {
   ThreadedActivity *j;
   char *script_path;
   NetworkInterface *iface;
+  bool adaptive_pool_size;
+  time_t deadline;
 
-  QueuedThreadData(ThreadedActivity *_j, char *_path, NetworkInterface *_iface) {
+  QueuedThreadData(ThreadedActivity *_j, char *_path, NetworkInterface *_iface,
+                   time_t _deadline) {
     j = _j, script_path = strdup(_path), iface = _iface;
+    deadline = _deadline;
   }
 
-  ~QueuedThreadData() { if(script_path) free(script_path); }
+  ~QueuedThreadData() {
+    if (script_path) free(script_path);
+  }
 };
-	
+
 class ThreadPool {
  private:
+  u_int16_t num_threads;
   bool terminating;
-  u_int8_t pool_size;
-  u_int16_t queue_len;
   pthread_cond_t condvar;
   Mutex *m;
-  pthread_t *threadsState;
-  std::queue <QueuedThreadData*> threads;
+#ifdef __linux__
+  cpu_set_t affinity_mask;
+#endif
+
+  std::vector<pthread_t> threadsState;
+  std::queue<QueuedThreadData *> threads;
+
+  QueuedThreadData *dequeueJob(bool waitIfEmpty);
+
+  /*
+    Creates and starts a new pool thread
+   */
+  bool spawn();
+  bool isQueueable(ThreadedActivityState cur_state);
 
-  QueuedThreadData* dequeueJob(bool waitIfEmpty);
-  
  public:
-  ThreadPool(u_int8_t _pool_size);
+  ThreadPool(char *comma_separated_affinity_mask = NULL);
   virtual ~ThreadPool();
 
   void shutdown();
   inline bool isTerminating() { return terminating; };
 
   void run();
-  bool queueJob(ThreadedActivity *j, char *path, NetworkInterface *iface);
+  bool queueJob(ThreadedActivity *ta, char *path, NetworkInterface *iface,
+                time_t scheduled_time, time_t deadline);
 };
 
-
 #endif /* _THREAD_POOL_H_ */
