@@ -34,9 +34,14 @@ class ThroughputStats {
  public:
   ThroughputStats();
   ThroughputStats(const ThroughputStats &thpts);
-  inline float getThpt()       const { return thpt;       };
+  void set(ThroughputStats *t);
+  inline float getThpt() const { return thpt; };
+
   inline ValueTrend getTrend() const { return thpt_trend; };
-  inline void sum(ThroughputStats *thpts) const { thpts->thpt += thpt, thpts->thpt_trend = thpt_trend; /* TODO: handle trend */};
+  inline void sum(ThroughputStats *thpts) const {
+    thpts->thpt += thpt,
+        thpts->thpt_trend = thpt_trend; /* TODO: handle trend */
+  };
   void updateStats(const struct timeval *tv, u_int64_t new_val);
   void resetStats();
 };
