@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-22 - ntop.org
+ * (C) 2015-23 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -43,12 +43,14 @@ class TimelineExtract {
     time_t to;
     char *bpf_filter;
     u_int64_t max_bytes;
-    const char * timeline_path;
+    const char *timeline_path;
   } extraction;
 
 #ifdef HAVE_PF_RING
-  pfring *openTimeline(const char * timeline_path, time_t from, time_t to, const char * bpf_filter);
-  pfring *openTimelineFromInterface(NetworkInterface *iface, time_t from, time_t to, const char * bpf_filter);
+  pfring *openTimeline(const char *timeline_path, time_t from, time_t to,
+                       const char *bpf_filter);
+  pfring *openTimelineFromInterface(NetworkInterface *iface, time_t from,
+                                    time_t to, const char *bpf_filter);
 #endif
 
  public:
@@ -64,13 +66,19 @@ class TimelineExtract {
   inline bool isRunning() { return running; };
   void stop();
   /* sync */
-  bool extractToDisk(u_int32_t id, NetworkInterface *iface, time_t from, time_t to, const char *bpf_filter, u_int64_t max_bytes, const char * timeline_path);
-  bool extractLive(struct mg_connection *conn, NetworkInterface *iface, time_t from, time_t to, const char *bpf_filter, const char * timeline_path);
+  bool extractToDisk(u_int32_t id, NetworkInterface *iface, time_t from,
+                     time_t to, const char *bpf_filter, u_int64_t max_bytes,
+                     const char *timeline_path);
+  bool extractLive(struct mg_connection *conn, NetworkInterface *iface,
+                   time_t from, time_t to, const char *bpf_filter,
+                   const char *timeline_path);
   /* async */
-  void runExtractionJob(u_int32_t id, NetworkInterface *iface, time_t from, time_t to, const char *bpf_filter, u_int64_t max_bytes, const char * timeline_path);
+  void runExtractionJob(u_int32_t id, NetworkInterface *iface, time_t from,
+                        time_t to, const char *bpf_filter, u_int64_t max_bytes,
+                        const char *timeline_path);
   void stopExtractionJob(u_int32_t id);
   void cleanupJob();
-  void getStatus(lua_State* vm);
+  void getStatus(lua_State *vm);
 };
 
 #endif /* _TIMELINE_EXTRACT_H_ */
