@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2018 - ntop.org
+ * (C) 2020-23 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,24 +26,29 @@
 
 class TimeseriesExporter {
  private:
-  time_t flushTime;
-  u_int32_t cursize;
-  u_int32_t num_exports;
-  int fd;
-  char fbase[PATH_MAX], fname[PATH_MAX+32];
+  static bool is_table_empty(lua_State *L, int index);
+  static int line_protocol_concat_table_fields(
+      lua_State *L, int index, char *buf, int buf_len,
+      int (*escape_fn)(char *outbuf, int outlen, const char *orig));
+
+ protected:
   NetworkInterface *iface;
-  u_int num_cached_entries; 
-  Mutex m;
-  bool dbCreated;
-  
-  void createDump();
-  
+
+  static int escape_spaces(char *buf, int buf_len, const char *unescaped);
+
  public:
   TimeseriesExporter(NetworkInterface *_if);
-  ~TimeseriesExporter();
+  virtual ~TimeseriesExporter();
 
-  void exportData(char *data, bool do_lock = true);
-  void flush();
+  static int line_protocol_write_line(lua_State *vm, char *dst_line,
+                                      int dst_line_len,
+                                      int (*escape_fn)(char *outbuf, int outlen,
+                                                       const char *orig));
+
+  virtual bool enqueueData(lua_State *vm, bool do_lock = true) = 0;
+  virtual char *dequeueData() = 0;
+  virtual u_int64_t queueLength() const { return 0; };
+  virtual void flush() = 0;
 };
 
 #endif /* _TS_EXPORTER_H_ */
