@@ -29,11 +29,15 @@ class BlacklistedFlowAlert : public FlowAlert {
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_blacklisted, alert_category_security}; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_blacklisted, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
-  BlacklistedFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) { };
-  ~BlacklistedFlowAlert() { };
+  BlacklistedFlowAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f) {};
+  ~BlacklistedFlowAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
