@@ -26,17 +26,18 @@
 
 class BroadcastNonUDPTrafficAlert : public FlowAlert {
  private:
-
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
 
  public:
-  static FlowAlertType getClassType()  { return { flow_alert_broadcast_non_udp_traffic, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_broadcast_non_udp_traffic, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
-  BroadcastNonUDPTrafficAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) { };
-  ~BroadcastNonUDPTrafficAlert() { };
+  BroadcastNonUDPTrafficAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){};
+  ~BroadcastNonUDPTrafficAlert(){};
 
-  FlowAlertType getAlertType() const { return getClassType();  }
+  FlowAlertType getAlertType() const { return getClassType(); }
 };
 
 #endif /* _BROADCAST_NON_UDP_TRAFFIC_ALERT_H_ */
