@@ -26,11 +26,15 @@
 
 class DNSDataExfiltrationAlert : public FlowAlert {
  public:
-  static FlowAlertType getClassType() { return { flow_alert_dns_data_exfiltration, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_WARNING; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_dns_data_exfiltration, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
- DNSDataExfiltrationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) { };
-  ~DNSDataExfiltrationAlert() { };
+  DNSDataExfiltrationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~DNSDataExfiltrationAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
