@@ -26,11 +26,15 @@
 
 class DataExfiltrationAlert : public FlowAlert {
  public:
-  static FlowAlertType getClassType() { return { flow_alert_data_exfiltration, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_data_exfiltration, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
- DataExfiltrationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) { };
-  ~DataExfiltrationAlert() { };
+  DataExfiltrationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~DataExfiltrationAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
