@@ -28,17 +28,20 @@ class ElephantFlowAlert : public FlowAlert {
  private:
   u_int64_t l2r_th, r2l_th;
 
-  ndpi_serializer *getAlertJSON(ndpi_serializer* serializer);
+  ndpi_serializer *getAlertJSON(ndpi_serializer *serializer);
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_elephant_flow, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_NOTICE; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_elephant_flow, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
- ElephantFlowAlert(FlowCheck *c, Flow *f, u_int64_t _l2r_th, u_int64_t _r2l_th) : FlowAlert(c, f) { 
+  ElephantFlowAlert(FlowCheck *c, Flow *f, u_int64_t _l2r_th, u_int64_t _r2l_th)
+      : FlowAlert(c, f) {
     l2r_th = _l2r_th;
     r2l_th = _r2l_th;
   };
-  ~ElephantFlowAlert() { };
+  ~ElephantFlowAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
