@@ -29,16 +29,23 @@ class FlowRiskKnownProtocolOnNonStandardPortAlert : public FlowRiskAlert {
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
 
  public:
-  static ndpi_risk_enum getClassRisk() { return NDPI_KNOWN_PROTOCOL_ON_NON_STANDARD_PORT; }
-  static FlowAlertType getClassType() { return FlowRiskAlerts::getFlowRiskAlertType(getClassRisk()); }
-  static u_int8_t      getDefaultScore() { return FlowRiskAlerts::getFlowRiskScore(getClassRisk()); }
+  static ndpi_risk_enum getClassRisk() {
+    return NDPI_KNOWN_PROTOCOL_ON_NON_STANDARD_PORT;
+  }
+  static FlowAlertType getClassType() {
+    return FlowRiskAlerts::getFlowRiskAlertType(getClassRisk());
+  }
+  static u_int8_t getDefaultScore() {
+    return FlowRiskAlerts::getFlowRiskScore(getClassRisk());
+  }
 
- FlowRiskKnownProtocolOnNonStandardPortAlert(FlowCheck *c, Flow *f) : FlowRiskAlert(c, f) { };
-  ~FlowRiskKnownProtocolOnNonStandardPortAlert() { };
+  FlowRiskKnownProtocolOnNonStandardPortAlert(FlowCheck* c, Flow* f)
+      : FlowRiskAlert(c, f){};
+  ~FlowRiskKnownProtocolOnNonStandardPortAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
-  ndpi_risk_enum getAlertRisk()  const { return getClassRisk();  }
-  u_int8_t       getAlertScore() const { return getDefaultScore(); }
+  ndpi_risk_enum getAlertRisk() const { return getClassRisk(); }
+  u_int8_t getAlertScore() const { return getDefaultScore(); }
 };
 
 #endif /* _FR_KNOWN_PROTOCOL_ON_NON_STANDARD_PORT_ALERT_H_ */
