@@ -26,11 +26,13 @@
 
 class InvalidDNSQueryAlert : public FlowAlert {
  public:
-  static FlowAlertType getClassType() { return { flow_alert_dns_invalid_query, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_NOTICE; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_dns_invalid_query, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
- InvalidDNSQueryAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) { };
-  ~InvalidDNSQueryAlert() { };
+  InvalidDNSQueryAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~InvalidDNSQueryAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
