@@ -26,14 +26,16 @@
 
 class LowGoodputFlowAlert : public FlowAlert {
  private:
-  ndpi_serializer *getAlertJSON(ndpi_serializer* serializer);
+  ndpi_serializer *getAlertJSON(ndpi_serializer *serializer);
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_low_goodput, alert_category_network }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_NOTICE; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_low_goodput, alert_category_network};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
- LowGoodputFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) {};
-  ~LowGoodputFlowAlert() {};
+  LowGoodputFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~LowGoodputFlowAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
