@@ -26,11 +26,13 @@
 
 class NedgeBlockedFlowAlert : public FlowAlert {
  public:
-  static FlowAlertType getClassType() { return { flow_alert_flow_blocked, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_WARNING; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_flow_blocked, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
- NedgeBlockedFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) {};
-  ~NedgeBlockedFlowAlert() { };
+  NedgeBlockedFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~NedgeBlockedFlowAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
