@@ -26,14 +26,16 @@
 
 class PeriodicityChangedAlert : public FlowAlert {
  private:
-  ndpi_serializer *getAlertJSON(ndpi_serializer* serializer);
+  ndpi_serializer *getAlertJSON(ndpi_serializer *serializer);
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_periodicity_changed, alert_category_network }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_INFO; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_periodicity_changed, alert_category_network};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_INFO; };
 
-  PeriodicityChangedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) { };
-  ~PeriodicityChangedAlert() { };
+  PeriodicityChangedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~PeriodicityChangedAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
