@@ -26,14 +26,18 @@
 
 class RemoteToLocalInsecureProtoAlert : public FlowAlert {
  private:
-  ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);  
+  ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_remote_to_local_insecure_proto, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_remote_to_local_insecure_proto, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
- RemoteToLocalInsecureProtoAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) {};
-  ~RemoteToLocalInsecureProtoAlert() {};
+  RemoteToLocalInsecureProtoAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){};
+  ~RemoteToLocalInsecureProtoAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
