@@ -24,11 +24,13 @@
 
 class TCPNoDataExchangedAlert : public FlowAlert {
  public:
-  static FlowAlertType getClassType() { return { flow_alert_tcp_no_data_exchanged, alert_category_network }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_NOTICE; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_tcp_no_data_exchanged, alert_category_network};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
- TCPNoDataExchangedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) {};
-  ~TCPNoDataExchangedAlert() {};
+  TCPNoDataExchangedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~TCPNoDataExchangedAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
