@@ -26,16 +26,20 @@
 
 class UnexpectedDHCPServerAlert : public UnexpectedServerAlert {
  private:
-
- protected: 
-  const IpAddress* getServerIP(Flow *f) { return(f->get_dhcp_srv_ip_addr()); }
+ protected:
+  const IpAddress *getServerIP(Flow *f) { return (f->get_dhcp_srv_ip_addr()); }
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_unexpected_dhcp_server, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_unexpected_dhcp_server, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
- UnexpectedDHCPServerAlert(FlowCheck *c, Flow *f) : UnexpectedServerAlert(c, f) {};
-  ~UnexpectedDHCPServerAlert() {};
+  UnexpectedDHCPServerAlert(FlowCheck *c, Flow *f)
+      : UnexpectedServerAlert(c, f){};
+  ~UnexpectedDHCPServerAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
