@@ -26,16 +26,20 @@
 
 class UnexpectedDNSServerAlert : public UnexpectedServerAlert {
  private:
-
  protected:
-  const IpAddress* getServerIP(Flow *f) { return(f->get_dns_srv_ip_addr()); }
+  const IpAddress *getServerIP(Flow *f) { return (f->get_dns_srv_ip_addr()); }
 
  public:
-  static FlowAlertType getClassType() { return { flow_alert_unexpected_dns_server, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_unexpected_dns_server, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
- UnexpectedDNSServerAlert(FlowCheck *c, Flow *f) : UnexpectedServerAlert(c, f) {};
-  ~UnexpectedDNSServerAlert() {};
+  UnexpectedDNSServerAlert(FlowCheck *c, Flow *f)
+      : UnexpectedServerAlert(c, f){};
+  ~UnexpectedDNSServerAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
