@@ -29,11 +29,13 @@ class UnexpectedServerAlert : public FlowAlert {
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
 
  protected:
-  virtual const IpAddress* getServerIP(Flow *f) { return(f->get_srv_ip_addr()); }
+  virtual const IpAddress* getServerIP(Flow* f) {
+    return (f->get_srv_ip_addr());
+  }
 
  public:
- UnexpectedServerAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) {};
-  ~UnexpectedServerAlert() {};
+  UnexpectedServerAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){};
+  ~UnexpectedServerAlert(){};
 };
 
 #endif /* _UNEXPECTED_HOST_ALERT_H_ */
