@@ -26,13 +26,16 @@
 
 class WebMiningAlert : public FlowAlert {
  private:
-  
  public:
-  static FlowAlertType getClassType() { return { flow_alert_web_mining_detected, alert_category_security }; }
-  static u_int8_t      getDefaultScore() { return SCORE_LEVEL_WARNING; };
+  static FlowAlertType getClassType() {
+    return {flow_alert_web_mining_detected, alert_category_security};
+  }
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
- WebMiningAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f) {};
-  ~WebMiningAlert() {};
+  WebMiningAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ~WebMiningAlert(){};
+
+  bool autoAck() const { return false; };
 
   FlowAlertType getAlertType() const { return getClassType(); }
 };
