@@ -26,19 +26,20 @@
 
 class BlacklistedFlow : public FlowCheck {
  private:
-  
  public:
-  BlacklistedFlow() : FlowCheck(ntopng_edition_community,
-				   false /* All interfaces */, false /* Don't exclude for nEdge */,
-				   false /* NOT only for nEdge */, true /* has_protocol_detected */,
-				   false /* has_periodic_update */, false /* has_flow_end */) {};
-  ~BlacklistedFlow() {};
+  BlacklistedFlow()
+      : FlowCheck(ntopng_edition_community, false /* All interfaces */,
+                  false /* Don't exclude for nEdge */,
+                  false /* NOT only for nEdge */,
+                  true /* has_protocol_detected */,
+                  false /* has_periodic_update */, false /* has_flow_end */){};
+  ~BlacklistedFlow(){};
 
   bool loadConfiguration(json_object *config);
   void protocolDetected(Flow *f);
   FlowAlert *buildAlert(Flow *f);
-  
-  std::string getName()          const { return(std::string("blacklisted")); }
+
+  std::string getName() const { return (std::string("blacklisted")); }
 };
 
 #endif /* _BLACKLISTED_FLOW_H_ */
