@@ -26,16 +26,25 @@
 
 class FlowRiskClearTextCredentials : public FlowRisk {
  private:
-  FlowAlertType getAlertType() const { return FlowRiskClearTextCredentialsAlert::getClassType(); }
+  FlowAlertType getAlertType() const {
+    return FlowRiskClearTextCredentialsAlert::getClassType();
+  }
 
  public:
-  FlowRiskClearTextCredentials() : FlowRisk() {};
-  ~FlowRiskClearTextCredentials() {};
+  FlowRiskClearTextCredentials() : FlowRisk(){};
+  ~FlowRiskClearTextCredentials(){};
 
-  FlowAlert *buildAlert(Flow *f) { return new FlowRiskClearTextCredentialsAlert(this, f); }
+  FlowAlert *buildAlert(Flow *f) {
+    return new FlowRiskClearTextCredentialsAlert(this, f);
+  }
 
-  std::string getName()        const { return(FlowRiskAlerts::getCheckName(FlowRiskClearTextCredentialsAlert::getClassRisk())); }
-  ndpi_risk_enum handledRisk()       { return FlowRiskClearTextCredentialsAlert::getClassRisk(); }
+  std::string getName() const {
+    return (FlowRiskAlerts::getCheckName(
+        FlowRiskClearTextCredentialsAlert::getClassRisk()));
+  }
+  ndpi_risk_enum handledRisk() {
+    return FlowRiskClearTextCredentialsAlert::getClassRisk();
+  }
 };
 
 #endif
