@@ -26,16 +26,25 @@
 
 class FlowRiskSMBInsecureVersion : public FlowRisk {
  private:
-  FlowAlertType getAlertType() const { return FlowRiskSMBInsecureVersionAlert::getClassType(); }
+  FlowAlertType getAlertType() const {
+    return FlowRiskSMBInsecureVersionAlert::getClassType();
+  }
 
  public:
-  FlowRiskSMBInsecureVersion() : FlowRisk() {};
-  ~FlowRiskSMBInsecureVersion() {};
+  FlowRiskSMBInsecureVersion() : FlowRisk(){};
+  ~FlowRiskSMBInsecureVersion(){};
 
-  FlowAlert *buildAlert(Flow *f)  { return new FlowRiskSMBInsecureVersionAlert(this, f); }
+  FlowAlert *buildAlert(Flow *f) {
+    return new FlowRiskSMBInsecureVersionAlert(this, f);
+  }
 
-  std::string getName()        const { return(FlowRiskAlerts::getCheckName(FlowRiskSMBInsecureVersionAlert::getClassRisk())); }
-  ndpi_risk_enum handledRisk() { return FlowRiskSMBInsecureVersionAlert::getClassRisk();       }
+  std::string getName() const {
+    return (FlowRiskAlerts::getCheckName(
+        FlowRiskSMBInsecureVersionAlert::getClassRisk()));
+  }
+  ndpi_risk_enum handledRisk() {
+    return FlowRiskSMBInsecureVersionAlert::getClassRisk();
+  }
 };
 
 #endif
