@@ -26,12 +26,17 @@
 
 class IECInvalidTransition : public FlowCheck {
  public:
-  IECInvalidTransition() : FlowCheck(ntopng_edition_community,
-				     true /* Packet Interfaces only */, false /* Don't exclude for nEdge */, false /* NOT only for nEdge */,
-				     false /* has_protocol_detected */, false /* has_periodic_update */, false /* has_flow_end */) {};
-  ~IECInvalidTransition() {};
-  
-  std::string getName() const { return(std::string("iec_invalid_transition")); }
+  IECInvalidTransition()
+      : FlowCheck(ntopng_edition_community, true /* Packet Interfaces only */,
+                  false /* Don't exclude for nEdge */,
+                  false /* NOT only for nEdge */,
+                  false /* has_protocol_detected */,
+                  false /* has_periodic_update */, false /* has_flow_end */){};
+  ~IECInvalidTransition(){};
+
+  std::string getName() const {
+    return (std::string("iec_invalid_transition"));
+  }
 };
 
 #endif /* _IEC_INVALID_TRANSITION_H_ */
