@@ -27,18 +27,21 @@
 class NotPurged : public FlowCheck {
  private:
   void checkNotPurged(Flow *f);
-  
+
  public:
- NotPurged() : FlowCheck(ntopng_edition_community,
-			    false /* All interfaces */, false /* Don't exclude for nEdge */, false /* NOT only for nEdge */,
-			    false /* has_protocol_detected */, true /* has_periodic_update */, true /* has_flow_end */) {};
-  ~NotPurged() {};
+  NotPurged()
+      : FlowCheck(ntopng_edition_community, false /* All interfaces */,
+                  false /* Don't exclude for nEdge */,
+                  false /* NOT only for nEdge */,
+                  false /* has_protocol_detected */,
+                  true /* has_periodic_update */, true /* has_flow_end */){};
+  ~NotPurged(){};
 
   void periodicUpdate(Flow *f);
   void flowEnd(Flow *f);
   FlowAlert *buildAlert(Flow *f);
-  
-  std::string getName()        const { return(std::string("not_purged")); }
+
+  std::string getName() const { return (std::string("not_purged")); }
 };
 
 #endif /* _NOT_PURGED_FLOW_H_ */
