@@ -26,12 +26,15 @@
 
 class ICMPFloodAlert : public FlowHitsAlert {
  private:
-  
  public:
-  static HostAlertType getClassType() { return { host_alert_icmp_flood, alert_category_security }; }
+  static HostAlertType getClassType() {
+    return {host_alert_icmp_flood, alert_category_security};
+  }
 
-  ICMPFloodAlert(HostCheck *c, Host *h, risk_percentage cli_pctg, u_int16_t hits, u_int64_t threshold, bool is_attacker) : FlowHitsAlert(c, h, cli_pctg, hits, threshold, is_attacker) {};
-  ~ICMPFloodAlert() {};
+  ICMPFloodAlert(HostCheck *c, Host *h, risk_percentage cli_pctg,
+                 u_int16_t hits, u_int64_t threshold, bool is_attacker)
+      : FlowHitsAlert(c, h, cli_pctg, hits, threshold, is_attacker){};
+  ~ICMPFloodAlert(){};
 
   HostAlertType getAlertType() const { return getClassType(); }
 };
