@@ -22,24 +22,25 @@
 #ifndef _NTP_TRAFFIC_ALERT_H_
 #define _NTP_TRAFFIC_ALERT_H_
 
-
 #include "ntop_includes.h"
 
-
 class NTPTrafficAlert : public HostAlert {
  private:
   u_int64_t ntp_bytes, ntp_bytes_threshold;
 
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
-  
- public:
-  static HostAlertType getClassType() { return { host_alert_ntp_traffic, alert_category_network }; }
 
-  NTPTrafficAlert(HostCheck *c, Host *f, risk_percentage cli_pctg, u_int64_t _ntp_bytes, u_int64_t _ntp_bytes_threshold);
-  ~NTPTrafficAlert() {};
-  
+ public:
+  static HostAlertType getClassType() {
+    return {host_alert_ntp_traffic, alert_category_network};
+  }
+
+  NTPTrafficAlert(HostCheck* c, Host* f, risk_percentage cli_pctg,
+                  u_int64_t _ntp_bytes, u_int64_t _ntp_bytes_threshold);
+  ~NTPTrafficAlert(){};
+
   HostAlertType getAlertType() const { return getClassType(); }
-  u_int8_t getAlertScore()     const { return SCORE_LEVEL_ERROR; };
+  u_int8_t getAlertScore() const { return SCORE_LEVEL_ERROR; };
 };
 
 #endif /* _NTP_TRAFFIC_ALERT_H_ */
