@@ -22,24 +22,25 @@
 #ifndef _P2P_TRAFFIC_ALERT_H_
 #define _P2P_TRAFFIC_ALERT_H_
 
-
 #include "ntop_includes.h"
 
-
 class P2PTrafficAlert : public HostAlert {
  private:
   u_int64_t p2p_bytes, p2p_bytes_threshold;
 
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
-  
- public:
-  static HostAlertType getClassType() { return { host_alert_p2p_traffic, alert_category_network }; }
 
-  P2PTrafficAlert(HostCheck *c, Host *f, risk_percentage cli_pctg, u_int64_t _p2p_bytes, u_int64_t _p2p_bytes_threshold);
-  ~P2PTrafficAlert() {};
-  
+ public:
+  static HostAlertType getClassType() {
+    return {host_alert_p2p_traffic, alert_category_network};
+  }
+
+  P2PTrafficAlert(HostCheck* c, Host* f, risk_percentage cli_pctg,
+                  u_int64_t _p2p_bytes, u_int64_t _p2p_bytes_threshold);
+  ~P2PTrafficAlert(){};
+
   HostAlertType getAlertType() const { return getClassType(); }
-  u_int8_t getAlertScore()     const { return SCORE_LEVEL_ERROR; };
+  u_int8_t getAlertScore() const { return SCORE_LEVEL_ERROR; };
 };
 
 #endif /* _P2P_TRAFFIC_ALERT_H_ */
