@@ -25,18 +25,20 @@
 #include "ntop_includes.h"
 
 class FlowFlood : public FlowHits {
-private:
+ private:
+ public:
+  FlowFlood() : FlowHits(){};
+  ~FlowFlood(){};
 
-public:
-  FlowFlood() : FlowHits() {};
-  ~FlowFlood() {};
-
-  FlowHitsAlert *allocAlert(Host *h, risk_percentage cli_pctg, u_int16_t hits, u_int64_t threshold, bool attacker) { return new FlowFloodAlert(this, h, cli_pctg, hits, threshold, attacker); };
+  FlowHitsAlert *allocAlert(Host *h, risk_percentage cli_pctg, u_int16_t hits,
+                            u_int64_t threshold, bool attacker) {
+    return new FlowFloodAlert(this, h, cli_pctg, hits, threshold, attacker);
+  };
 
   void periodicUpdate(Host *h, HostAlert *engaged_alert);
 
   HostCheckID getID() const { return host_check_flow_flood; }
-  std::string getName()      const { return(std::string("flow_flood")); }
+  std::string getName() const { return (std::string("flow_flood")); }
 };
 
 #endif
