@@ -27,7 +27,6 @@
 
 #include "host_checks/CountriesContacts.h"
 #include "host_checks/CustomHostLuaScript.h"
-#include "host_checks/ExternalHostScript.h"
 
 #include "host_checks/FlowHits.h"
 #include "host_checks/FlowFlood.h"
@@ -59,6 +58,5 @@
 #include "host_checks/SNMPFlood.h"
 #include "host_checks/ScoreAnomaly.h"
 #include "host_checks/FlowAnomaly.h"
-#include "host_checks/HostMACReassociation.h"
 #endif
 #endif /* _HOST_CHECKS_INCLUDES_H_ */
