@@ -26,17 +26,17 @@
 #ifndef TCP_ESTABLISHED
 /* /usr/include/netinet/tcp.h */
 enum {
-      TCP_ESTABLISHED = 1,
-      TCP_SYN_SENT,
-      TCP_SYN_RECV,
-      TCP_FIN_WAIT1,
-      TCP_FIN_WAIT2,
-      TCP_TIME_WAIT,
-      TCP_CLOSE,
-      TCP_CLOSE_WAIT,
-      TCP_LAST_ACK,
-      TCP_LISTEN,
-      TCP_CLOSING   /* now a valid state */
+  TCP_ESTABLISHED = 1,
+  TCP_SYN_SENT,
+  TCP_SYN_RECV,
+  TCP_FIN_WAIT1,
+  TCP_FIN_WAIT2,
+  TCP_TIME_WAIT,
+  TCP_CLOSE,
+  TCP_CLOSE_WAIT,
+  TCP_LAST_ACK,
+  TCP_LISTEN,
+  TCP_CLOSING /* now a valid state */
 };
 #endif
 #endif
@@ -45,6 +45,7 @@ typedef struct {
   const char *string;
   int64_t int_num;
   double double_num;
+  bool boolean;
 } ParsedValue;
 
 typedef enum {
@@ -53,7 +54,8 @@ typedef enum {
   mask_remote_hosts = 2
 } HostMask;
 
-/* Struct used to pass parameters when walking hosts and flows periodically to update their stats */
+/* Struct used to pass parameters when walking hosts and flows periodically to
+ * update their stats */
 class AlertCheckLuaEngine;
 class ThreadedActivityStats;
 typedef struct {
@@ -90,9 +92,11 @@ typedef enum {
   check_category_internals = 2,
   check_category_network = 3,
   check_category_system = 4,
-  check_category_ids_ips = 5, /* Intrusion prevention. Used for checks that add hosts to the jailed pool */
+  check_category_ids_ips = 5, /* Intrusion prevention. Used for checks that add
+                                 hosts to the jailed pool */
   MAX_NUM_SCRIPT_CATEGORIES
-} CheckCategory; /* Keep in sync with checks.check_categories in scripts/lua/modules/checks.lua  */
+} CheckCategory; /* Keep in sync with checks.check_categories in
+                    scripts/lua/modules/checks.lua  */
 
 typedef enum {
   alert_category_other = 0,
@@ -102,7 +106,8 @@ typedef enum {
   alert_category_system = 4,
   alert_category_ids_ips = 5,
   MAX_NUM_ALERT_CATEGORIES
-} AlertCategory; /* TODO: keep in sync with CheckCategory until we remove CheckCategory */
+} AlertCategory; /* TODO: keep in sync with CheckCategory until we remove
+                    CheckCategory */
 
 /*
   This is a subset of CheckCategory as flow scripts fall only in this subset
@@ -134,6 +139,7 @@ typedef enum {
   location_private_only, /* Only 192.168.0.0/16 and other private */
   location_public_only,  /* Only non-private */
   location_all,
+  location_broadcat_multicast_only
 } LocationPolicy;
 
 typedef enum {
@@ -165,14 +171,14 @@ typedef u_int32_t AlertType;
 #define alert_none ((u_int8_t)-1)
 
 typedef enum {
-  alert_level_none      = 0,
-  alert_level_debug     = 1,
-  alert_level_info      = 2,
-  alert_level_notice    = 3,
-  alert_level_warning   = 4,
-  alert_level_error     = 5,
-  alert_level_critical  = 6,
-  alert_level_alert     = 7,
+  alert_level_none = 0,
+  alert_level_debug = 1,
+  alert_level_info = 2,
+  alert_level_notice = 3,
+  alert_level_warning = 4,
+  alert_level_error = 5,
+  alert_level_critical = 6,
+  alert_level_alert = 7,
   alert_level_emergency = 8,
   ALERT_LEVEL_MAX_LEVEL = 9
 } AlertLevel;
@@ -207,49 +213,27 @@ typedef enum {
   Keep in sync with alert_entities.lua entity_id
  */
 typedef enum {
-  alert_entity_none                = -1,
-  alert_entity_interface           =  0,
-  alert_entity_host                =  1,
-  alert_entity_network             =  2,
-  alert_entity_snmp_device         =  3,
-  alert_entity_flow                =  4,
-  alert_entity_mac                 =  5,
-  alert_entity_host_pool           =  6,
-  alert_entity_user                =  7,
-  alert_entity_am_host             =  8,
-  alert_entity_system              =  9,
-  alert_entity_test                = 10,
-  alert_entity_asn                 = 11,
-  alert_entity_l7                  = 12,
+  alert_entity_none = -1,
+  alert_entity_interface = 0,
+  alert_entity_host = 1,
+  alert_entity_network = 2,
+  alert_entity_snmp_device = 3,
+  alert_entity_flow = 4,
+  alert_entity_mac = 5,
+  alert_entity_host_pool = 6,
+  alert_entity_user = 7,
+  alert_entity_am_host = 8,
+  alert_entity_system = 9,
+  alert_entity_test = 10,
+  alert_entity_asn = 11,
+  alert_entity_l7 = 12,
 
   /* Add new entities above ^ and do not exceed alert_entity_other */
-  alert_entity_other               = 15,
-  ALERT_ENTITY_MAX_NUM_ENTITIES    = 16
+  alert_entity_other = 15,
+  ALERT_ENTITY_MAX_NUM_ENTITIES = 16
 } AlertEntity;
 
-typedef enum {
-  IPV4 = 4,
-  IPV6 = 6
-} IPVersion;
-
-/* Used to queue/dequeue elements in recipient queues via AlertFifoQueue.h */
-typedef struct {
-  AlertLevel alert_severity;
-  AlertCategory alert_category;
-  union {
-    /* alert_entity_host */
-    struct {
-      u_int16_t host_pool;
-    } host;
-    /* alert_entity_flow */
-    struct {
-      u_int16_t cli_host_pool;
-      u_int16_t srv_host_pool;
-    } flow;
-  } pools;
-  u_int32_t score;
-  char *alert;
-} AlertFifoItem;
+typedef enum { IPV4 = 4, IPV6 = 6 } IPVersion;
 
 struct zmq_msg_hdr_v0 {
   char url[32];
@@ -271,6 +255,16 @@ struct zmq_msg_hdr_v2 {
   u_int32_t msg_id, source_id;
 };
 
+typedef struct {
+  char *endpoint;
+  void *socket;
+} zmq_subscriber;
+
+typedef struct {
+  u_int32_t last_seen;
+  u_int32_t last_msg_id;
+} zmq_probe;
+
 typedef u_int8_t dump_mac_t[DUMP_MAC_SIZE];
 typedef char macstr_t[MACSTR_SIZE];
 
@@ -278,7 +272,15 @@ typedef struct {
   u_int8_t counter[NUM_MINUTES_PER_DAY];
 } activity_bitmap;
 
-enum SQLfield { SF_NONE, SF_SELECT, SF_FROM, SF_WHERE, SF_AND, SF_LIMIT, SF_TOK };
+enum SQLfield {
+  SF_NONE,
+  SF_SELECT,
+  SF_FROM,
+  SF_WHERE,
+  SF_AND,
+  SF_LIMIT,
+  SF_TOK
+};
 
 #ifndef __OpenBSD__
 #define bpf_timeval timeval
@@ -306,7 +308,7 @@ typedef struct {
   char *cmd_line;
   char *pkg_name, *father_pkg_name;
   char *uid_name, *father_uid_name;
-  u_int32_t uid /* User Id */, gid; /* Group Id */
+  u_int32_t uid /* User Id */, gid;               /* Group Id */
   u_int32_t father_uid /* User Id */, father_gid; /* Group Id */
   u_int32_t actual_memory, peak_memory;
 } ProcessInfo;
@@ -349,8 +351,8 @@ typedef struct {
   u_int32_t remapped_app_id;
 } custom_app_t;
 
-/* IMPORTANT: whenever the Parsed_FlowSerial is changed, nProbe must be updated too */
-
+/* IMPORTANT: whenever the Parsed_FlowSerial is changed, nProbe must be updated
+ * too */
 
 typedef struct zmq_remote_stats {
   char remote_ifname[32], remote_ifaddress[64];
@@ -358,12 +360,14 @@ typedef struct zmq_remote_stats {
   char remote_probe_version[64], remote_probe_os[64];
   char remote_probe_license[64], remote_probe_edition[64];
   char remote_probe_maintenance[64];
-  u_int8_t  source_id, num_exporters;
+  u_int32_t source_id, num_exporters;
   u_int64_t remote_bytes, remote_pkts, num_flow_exports;
   u_int32_t remote_ifspeed, remote_time, local_time, avg_bps, avg_pps;
-  u_int32_t remote_lifetime_timeout, remote_idle_timeout, remote_collected_lifetime_timeout;
+  u_int32_t remote_lifetime_timeout, remote_idle_timeout,
+      remote_collected_lifetime_timeout;
   u_int32_t export_queue_full, too_many_flows, elk_flow_drops,
-    sflow_pkt_sample_drops, flow_collection_drops, flow_collection_udp_socket_drops;
+      sflow_pkt_sample_drops, flow_collection_drops,
+      flow_collection_udp_socket_drops;
   struct {
     u_int64_t nf_ipfix_flows;
     u_int64_t sflow_samples;
@@ -386,14 +390,14 @@ typedef struct zmq_field_value_map {
 } ZMQ_FieldValueMap;
 
 struct vm_ptree {
-  lua_State* vm;
+  lua_State *vm;
   AddressTree *ptree;
 };
 
 struct active_flow_stats {
   u_int32_t num_flows,
-    ndpi_bytes[NDPI_MAX_SUPPORTED_PROTOCOLS+NDPI_MAX_NUM_CUSTOM_PROTOCOLS],
-    breeds_bytes[NUM_BREEDS];
+      ndpi_bytes[NDPI_MAX_SUPPORTED_PROTOCOLS + NDPI_MAX_NUM_CUSTOM_PROTOCOLS],
+      breeds_bytes[NUM_BREEDS];
 };
 
 struct grev1_header {
@@ -411,107 +415,118 @@ typedef enum {
   flow_check_periodic_update,
   flow_check_flow_end,
   flow_check_flow_begin,
-  flow_check_flow_none /* Flow check not bound to protoDetected, periodicUpdate, flowEnd, flowBegin */
+  flow_check_flow_none /* Flow check not bound to protoDetected, periodicUpdate,
+                          flowEnd, flowBegin */
 } FlowChecks;
 
-/* NOTE: Throw modules/alert_keys.lua as it has been merged with modules/alert_keys.lua */
+/* NOTE: Throw modules/alert_keys.lua as it has been merged with
+ * modules/alert_keys.lua */
 /* NOTE: keep in sync with modules/alert_keys/flow_alert_keys.lua */
 typedef enum {
-  flow_alert_normal                               = 0,
-  flow_alert_blacklisted                          = 1,
-  flow_alert_blacklisted_country                  = 2,
-  flow_alert_flow_blocked                         = 3,
-  flow_alert_data_exfiltration                    = 4,
-  flow_alert_device_protocol_not_allowed          = 5,
-  flow_alert_dns_data_exfiltration                = 6,
-  flow_alert_dns_invalid_query                    = 7,
-  flow_alert_elephant_flow                        = 8,
-  flow_alert_notused_1                            = 9,
-  flow_alert_external                             = 10,
-  flow_alert_longlived                            = 11,
-  flow_alert_low_goodput                          = 12,
-  flow_alert_malicious_signature                  = 13,
-  flow_alert_internals                            = 14,
-  flow_alert_notused_3                            = 15,
-  flow_alert_remote_to_remote                     = 16,
-  flow_alert_notused_4                            = 17,
-  flow_alert_notused_5                            = 18,
-  flow_alert_tcp_packets_issues                   = 19,
-  flow_alert_tcp_connection_refused               = 20,
-  flow_alert_notused_7                            = 21,
-  flow_alert_ndpi_tls_certificate_expired         = 22,
-  flow_alert_ndpi_tls_certificate_mismatch        = 23,
-  flow_alert_ndpi_tls_old_protocol_version        = 24,
-  flow_alert_ndpi_tls_unsafe_ciphers              = 25,
-  flow_alert_ndpi_unidirectional_traffic          = 26,
-  flow_alert_web_mining_detected                  = 27,
-  flow_alert_ndpi_tls_certificate_selfsigned      = 28,
-  flow_alert_ndpi_binary_application_transfer     = 29,
-  flow_alert_ndpi_known_proto_on_non_std_port     = 30,
-  flow_alert_noutused_8                           = 31,
-  flow_alert_unexpected_dhcp_server               = 32,
-  flow_alert_unexpected_dns_server                = 33,
-  flow_alert_unexpected_smtp_server               = 34,
-  flow_alert_unexpected_ntp_server                = 35,
-  flow_alert_zero_tcp_window                      = 36,
-  flow_alert_iec_invalid_transition               = 37,
-  flow_alert_remote_to_local_insecure_proto       = 38,
-  flow_alert_ndpi_url_possible_xss                = 39,
-  flow_alert_ndpi_url_possible_sql_injection      = 40,
-  flow_alert_ndpi_url_possible_rce_injection      = 41,
-  flow_alert_ndpi_http_suspicious_user_agent      = 42,
-  flow_alert_ndpi_http_numeric_ip_host            = 43,
-  flow_alert_ndpi_http_suspicious_url             = 44,
-  flow_alert_ndpi_http_suspicious_header          = 45,
-  flow_alert_ndpi_tls_not_carrying_https          = 46,
-  flow_alert_ndpi_suspicious_dga_domain           = 47,
-  flow_alert_ndpi_malformed_packet                = 48,
-  flow_alert_ndpi_ssh_obsolete_server             = 49,
-  flow_alert_ndpi_smb_insecure_version            = 50,
-  flow_alert_ndpi_tls_suspicious_esni_usage       = 51,
-  flow_alert_ndpi_unsafe_protocol                 = 52,
-  flow_alert_ndpi_dns_suspicious_traffic          = 53,
-  flow_alert_ndpi_tls_missing_sni                 = 54,
-  flow_alert_iec_unexpected_type_id               = 55,
-  flow_alert_tcp_no_data_exchanged                = 56,
-  flow_alert_remote_access                        = 57,
-  flow_alert_lateral_movement                     = 58,
-  flow_alert_periodicity_changed                  = 59,
-  flow_alert_ndpi_tls_cert_validity_too_long      = 60,
-  flow_alert_ndpi_ssh_obsolete_client             = 61,
-  flow_alert_ndpi_clear_text_credentials          = 62,
-  flow_alert_ndpi_http_suspicious_content         = 63,
-  flow_alert_ndpi_dns_large_packet                = 64,
-  flow_alert_ndpi_dns_fragmented                  = 65,
-  flow_alert_ndpi_invalid_characters              = 66,
-  flow_alert_broadcast_non_udp_traffic            = 67,
-  flow_alert_ndpi_possible_exploit                = 68,
+  flow_alert_normal = 0,
+  flow_alert_blacklisted = 1,
+  flow_alert_blacklisted_country = 2,
+  flow_alert_flow_blocked = 3,
+  flow_alert_data_exfiltration = 4,
+  flow_alert_device_protocol_not_allowed = 5,
+  flow_alert_dns_data_exfiltration = 6,
+  flow_alert_dns_invalid_query = 7,
+  flow_alert_elephant_flow = 8,
+  flow_alert_notused_1 = 9,
+  flow_alert_external = 10,
+  flow_alert_longlived = 11,
+  flow_alert_low_goodput = 12,
+  flow_alert_notused_2 = 13,
+  flow_alert_internals = 14,
+  flow_alert_notused_3 = 15,
+  flow_alert_remote_to_remote = 16,
+  flow_alert_notused_4 = 17,
+  flow_alert_notused_5 = 18,
+  flow_alert_tcp_packets_issues = 19,
+  flow_alert_tcp_connection_refused = 20,
+  flow_alert_notused_7 = 21,
+  flow_alert_ndpi_tls_certificate_expired = 22,
+  flow_alert_ndpi_tls_certificate_mismatch = 23,
+  flow_alert_ndpi_tls_old_protocol_version = 24,
+  flow_alert_ndpi_tls_unsafe_ciphers = 25,
+  flow_alert_ndpi_unidirectional_traffic = 26,
+  flow_alert_web_mining_detected = 27,
+  flow_alert_ndpi_tls_certificate_selfsigned = 28,
+  flow_alert_ndpi_binary_application_transfer = 29,
+  flow_alert_ndpi_known_proto_on_non_std_port = 30,
+  flow_alert_noutused_8 = 31,
+  flow_alert_unexpected_dhcp_server = 32,
+  flow_alert_unexpected_dns_server = 33,
+  flow_alert_unexpected_smtp_server = 34,
+  flow_alert_unexpected_ntp_server = 35,
+  flow_alert_zero_tcp_window = 36,
+  flow_alert_iec_invalid_transition = 37,
+  flow_alert_remote_to_local_insecure_proto = 38,
+  flow_alert_ndpi_url_possible_xss = 39,
+  flow_alert_ndpi_url_possible_sql_injection = 40,
+  flow_alert_ndpi_url_possible_rce_injection = 41,
+  flow_alert_ndpi_http_suspicious_user_agent = 42,
+  flow_alert_ndpi_numeric_ip_host = 43,
+  flow_alert_ndpi_http_suspicious_url = 44,
+  flow_alert_ndpi_http_suspicious_header = 45,
+  flow_alert_ndpi_tls_not_carrying_https = 46,
+  flow_alert_ndpi_suspicious_dga_domain = 47,
+  flow_alert_ndpi_malformed_packet = 48,
+  flow_alert_ndpi_ssh_obsolete_server = 49,
+  flow_alert_ndpi_smb_insecure_version = 50,
+  flow_alert_ndpi_tls_suspicious_esni_usage = 51,
+  flow_alert_ndpi_unsafe_protocol = 52,
+  flow_alert_ndpi_dns_suspicious_traffic = 53,
+  flow_alert_ndpi_tls_missing_sni = 54,
+  flow_alert_iec_unexpected_type_id = 55,
+  flow_alert_tcp_no_data_exchanged = 56,
+  flow_alert_remote_access = 57,
+  flow_alert_lateral_movement = 58,
+  flow_alert_periodicity_changed = 59,
+  flow_alert_ndpi_tls_cert_validity_too_long = 60,
+  flow_alert_ndpi_ssh_obsolete_client = 61,
+  flow_alert_ndpi_clear_text_credentials = 62,
+  flow_alert_ndpi_http_suspicious_content = 63,
+  flow_alert_ndpi_dns_large_packet = 64,
+  flow_alert_ndpi_dns_fragmented = 65,
+  flow_alert_ndpi_invalid_characters = 66,
+  flow_alert_broadcast_non_udp_traffic = 67,
+  flow_alert_ndpi_possible_exploit = 68,
   flow_alert_ndpi_tls_certificate_about_to_expire = 69,
-  flow_alert_ndpi_punicody_idn                    = 70,
-  flow_alert_ndpi_error_code_detected             = 71,
-  flow_alert_ndpi_http_crawler_bot                = 72,
-  flow_alert_ndpi_suspicious_entropy              = 73,
-  flow_alert_iec_invalid_command_transition       = 74,
-  flow_alert_connection_failed                    = 75,
-  flow_alert_ndpi_anonymous_subscriber            = 76,
-  flow_alert_unidirectional_traffic               = 77,
+  flow_alert_ndpi_punicody_idn = 70,
+  flow_alert_ndpi_error_code_detected = 71,
+  flow_alert_ndpi_http_crawler_bot = 72,
+  flow_alert_ndpi_suspicious_entropy = 73,
+  flow_alert_iec_invalid_command_transition = 74,
+  flow_alert_connection_failed = 75,
+  flow_alert_ndpi_anonymous_subscriber = 76,
+  flow_alert_unidirectional_traffic = 77,
   flow_alert_ndpi_desktop_or_file_sharing_session = 78,
-  flow_alert_ndpi_malicious_ja3                   = 79,
-  flow_alert_ndpi_malicious_sha1_certificate      = 80,
-  flow_alert_ndpi_tls_uncommon_alpn               = 81,
-  flow_alert_ndpi_tls_suspicious_extension        = 82,
-  flow_alert_ndpi_tls_fatal_alert                 = 83,
-  flow_alert_ndpi_http_obsolete_server            = 84,
-  flow_alert_ndpi_risky_asn                       = 85,
-  flow_alert_ndpi_risky_domain                    = 86,
-  flow_alert_custom_lua_script                    = 87,
-  flow_alert_ndpi_periodic_flow                   = 88,
-  flow_alert_ndpi_minor_issues                    = 89,
-  flow_alert_ndpi_tcp_issues                      = 90,
+  flow_alert_ndpi_malicious_ja3 = 79,
+  flow_alert_ndpi_malicious_sha1_certificate = 80,
+  flow_alert_ndpi_tls_uncommon_alpn = 81,
+  flow_alert_ndpi_tls_suspicious_extension = 82,
+  flow_alert_ndpi_tls_fatal_alert = 83,
+  flow_alert_ndpi_http_obsolete_server = 84,
+  flow_alert_ndpi_risky_asn = 85,
+  flow_alert_ndpi_risky_domain = 86,
+  flow_alert_custom_lua_script = 87,
+  flow_alert_ndpi_periodic_flow = 88,
+  flow_alert_ndpi_minor_issues = 89,
+  flow_alert_ndpi_tcp_issues = 90,
+  flow_alert_vlan_bidirectional_traffic = 91,
+  flow_alert_rare_destination = 92,
+  flow_alert_modbus_unexpected_function_code = 93,
+  flow_alert_modbus_too_many_exceptions = 94,
+  flow_alert_modbus_invalid_transition = 95,
+  flow_alert_ndpi_fully_encrypted = 96,
+  flow_alert_ndpi_tls_alpn_sni_mismatch = 97,
+  flow_alert_ndpi_malware_host_contacted = 98,
   
   MAX_DEFINED_FLOW_ALERT_TYPE, /* Leave it as last member */
 
-  MAX_FLOW_ALERT_TYPE = 127 /* Constrained by `Bitmap128 alert_map` inside Flow.h */
+  MAX_FLOW_ALERT_TYPE =
+      127 /* Constrained by `Bitmap128 alert_map` inside Flow.h */
 } FlowAlertTypeEnum;
 
 typedef struct {
@@ -529,37 +544,37 @@ typedef struct {
    returned with HostCheckID getID()
 */
 typedef enum {
-  host_alert_normal                      =  0,
-  host_alert_smtp_server_contacts        =  1,
-  host_alert_dns_server_contacts         =  2,
-  host_alert_ntp_server_contacts         =  3,
-  host_alert_flow_flood                  =  4,
-  host_alert_syn_scan                    =  5,
-  host_alert_syn_flood                   =  6,
-  host_alert_domain_names_contacts       =  7,
-  host_alert_p2p_traffic                 =  8,
-  host_alert_dns_traffic                 =  9,
-  host_alert_flows_anomaly               = 10,
-  host_alert_score_anomaly               = 11,
-  host_alert_remote_connection           = 12,
-  host_alert_host_log                    = 13,
-  host_alert_dangerous_host              = 14,
-  host_alert_ntp_traffic                 = 15,
-  host_alert_countries_contacts          = 16,
-  host_alert_score_threshold             = 17,
-  host_alert_icmp_flood                  = 18,
-  host_alert_pkt_threshold               = 19,
-  host_alert_scan_detected               = 20,
-  host_alert_fin_scan                    = 21,
-  host_alert_dns_flood                   = 22,
-  host_alert_snmp_flood                  = 23,
-  host_alert_custom_lua_script           = 24,
-  host_alert_rst_scan                    = 25,
-  host_alert_traffic_volume              = 26,
-  host_alert_external_script             = 27,
+  host_alert_normal = 0,
+  host_alert_smtp_server_contacts = 1,
+  host_alert_dns_server_contacts = 2,
+  host_alert_ntp_server_contacts = 3,
+  host_alert_flow_flood = 4,
+  host_alert_syn_scan = 5,
+  host_alert_syn_flood = 6,
+  host_alert_domain_names_contacts = 7,
+  host_alert_p2p_traffic = 8,
+  host_alert_dns_traffic = 9,
+  host_alert_flows_anomaly = 10,
+  host_alert_score_anomaly = 11,
+  host_alert_remote_connection = 12,
+  host_alert_host_log = 13,
+  host_alert_dangerous_host = 14,
+  host_alert_ntp_traffic = 15,
+  host_alert_countries_contacts = 16,
+  host_alert_score_threshold = 17,
+  host_alert_icmp_flood = 18,
+  host_alert_pkt_threshold = 19,
+  host_alert_scan_detected = 20,
+  host_alert_fin_scan = 21,
+  host_alert_dns_flood = 22,
+  host_alert_snmp_flood = 23,
+  host_alert_custom_lua_script = 24,
+  host_alert_rst_scan = 25,
+  host_alert_traffic_volume = 26,
+  host_alert_external_script = 27, /* Triggered from Lua (see rest/v2/trigger/host/alert.lua) */
 
   MAX_DEFINED_HOST_ALERT_TYPE, /* Leave it as last member */
-  MAX_HOST_ALERT_TYPE = 32 /* Constrained by HostAlertBitmap */
+  MAX_HOST_ALERT_TYPE = 32     /* Constrained by HostAlertBitmap */
 } HostAlertTypeEnum;
 
 typedef struct {
@@ -600,21 +615,36 @@ typedef enum {
   host_check_snmp_flood,
   host_check_custom_lua_script,
   host_check_rst_scan,
-  host_check_traffic_volume, /* Dummy check (see ntop_interface_update_ip_reassignment) */
+  host_check_traffic_volume, /* Dummy check (see
+                                ntop_interface_update_ip_reassignment) */
   host_check_external_script,
-  
+
   NUM_DEFINED_HOST_CHECKS, /* Leave it as last member */
 } HostCheckID;
 
 typedef enum {
-  flow_lua_call_exec_status_ok = 0,                             /* Call executed successfully                                */
-  flow_lua_call_exec_status_not_executed_script_failure,        /* Call NOT executed as the script failed to load (syntax?)   */
-  flow_lua_call_exec_status_not_executed_no_time_left,          /* Call NOT executed as the deadline was approaching         */
-  flow_lua_call_exec_status_not_executed_unknown_call,          /* Call NOT executed as the function to be called is unknown */
-  flow_lua_call_exec_status_not_executed_shutdown_in_progress,  /* Call NOT executed as a shutdown was in progress           */
-  flow_lua_call_exec_status_not_executed_vm_not_allocated,      /* Call NOT executed as the vm wasn't allocated              */
-  flow_lua_call_exec_status_not_executed_not_pending,           /* Call NOT executed as other hooks have already been exec.  */
-  flow_lua_call_exec_status_unsupported_call,                   /* Call NOT executed as not supported                        */
+  flow_lua_call_exec_status_ok = 0, /* Call executed successfully */
+  flow_lua_call_exec_status_not_executed_script_failure, /* Call NOT executed as
+                                                            the script failed to
+                                                            load (syntax?)   */
+  flow_lua_call_exec_status_not_executed_no_time_left,   /* Call NOT executed as
+                                                            the deadline was
+                                                            approaching         */
+  flow_lua_call_exec_status_not_executed_unknown_call,   /* Call NOT executed as
+                                                            the function to be
+                                                            called is unknown */
+  flow_lua_call_exec_status_not_executed_shutdown_in_progress, /* Call NOT
+                                                                  executed as a
+                                                                  shutdown was
+                                                                  in progress */
+  flow_lua_call_exec_status_not_executed_vm_not_allocated, /* Call NOT executed
+                                                              as the vm wasn't
+                                                              allocated */
+  flow_lua_call_exec_status_not_executed_not_pending, /* Call NOT executed as
+                                                         other hooks have
+                                                         already been exec.  */
+  flow_lua_call_exec_status_unsupported_call, /* Call NOT executed as not
+                                                 supported */
 } FlowLuaCallExecStatus;
 
 typedef enum {
@@ -640,7 +670,7 @@ typedef enum {
   column_device_ip,
   column_in_index,
   column_out_index,
-  column_serial,
+  column_key,
   /* Hosts */
   column_ip,
   column_alerts,
@@ -653,7 +683,7 @@ typedef enum {
   column_country,
   column_mac,
   column_os,
-  column_num_flows, /* = column_incomingflows + column_outgoingflows */
+  column_num_flows,         /* = column_incomingflows + column_outgoingflows */
   column_num_dropped_flows, /* for bridge interfaces */
   /* column_thpt, */
   column_traffic,
@@ -685,8 +715,8 @@ typedef enum {
   column_first_seen,
   column_obs_point,
   column_alerted_flows,
-  column_tcp_unresp_as_client,
-  column_tcp_unresp_as_server
+  column_tcp_udp_unresp_as_client,
+  column_tcp_udp_unresp_as_server
 } sortField;
 
 typedef struct {
@@ -694,8 +724,8 @@ typedef struct {
   u_int32_t deviceIP, ifIndex, ifType, ifSpeed;
   char *ifName;
   bool ifFullDuplex, ifAdminStatus, ifOperStatus, ifPromiscuousMode;
-  u_int64_t ifInOctets, ifInPackets, ifInErrors,
-    ifOutOctets, ifOutPackets, ifOutErrors;
+  u_int64_t ifInOctets, ifInPackets, ifInErrors, ifOutOctets, ifOutPackets,
+      ifOutErrors;
   ContainerInfo container_info;
   bool container_info_set;
 } sFlowInterfaceStats;
@@ -761,15 +791,15 @@ class StringCache {
 PACK_ON
 
 struct arp_header {
-  u_int16_t ar_hrd;/* Format of hardware address.  */
-  u_int16_t ar_pro;/* Format of protocol address.  */
-  u_int8_t  ar_hln;/* Length of hardware address.  */
-  u_int8_t  ar_pln;/* Length of protocol address.  */
-  u_int16_t ar_op;/* ARP opcode (command).  */
-  u_char arp_sha[6];/* sender hardware address */
-  u_int32_t arp_spa;/* sender protocol address */
-  u_char arp_tha[6];/* target hardware address */
-  u_int32_t arp_tpa;/* target protocol address */
+  u_int16_t ar_hrd;  /* Format of hardware address.  */
+  u_int16_t ar_pro;  /* Format of protocol address.  */
+  u_int8_t ar_hln;   /* Length of hardware address.  */
+  u_int8_t ar_pln;   /* Length of protocol address.  */
+  u_int16_t ar_op;   /* ARP opcode (command).  */
+  u_char arp_sha[6]; /* sender hardware address */
+  u_int32_t arp_spa; /* sender protocol address */
+  u_char arp_tha[6]; /* target hardware address */
+  u_int32_t arp_tpa; /* target protocol address */
 } PACK_OFF;
 
 PACK_ON
@@ -781,22 +811,22 @@ struct arp_packet {
 
 PACK_ON
 struct dhcp_packet {
-  u_int8_t	msgType;
-  u_int8_t	htype;
-  u_int8_t	hlen;
-  u_int8_t	hops;
-  u_int32_t	xid;/* 4 */
-  u_int16_t	secs;/* 8 */
-  u_int16_t	flags;
-  u_int32_t	ciaddr;/* 12 */
-  u_int32_t	yiaddr;/* 16 */
-  u_int32_t	siaddr;/* 20 */
-  u_int32_t	giaddr;/* 24 */
-  u_int8_t	chaddr[16]; /* 28 */
-  u_int8_t	sname[64]; /* 44 */
-  u_int8_t	file[128]; /* 108 */
-  u_int32_t	magic; /* 236 */
-  u_int8_t	options[308];
+  u_int8_t msgType;
+  u_int8_t htype;
+  u_int8_t hlen;
+  u_int8_t hops;
+  u_int32_t xid;  /* 4 */
+  u_int16_t secs; /* 8 */
+  u_int16_t flags;
+  u_int32_t ciaddr;    /* 12 */
+  u_int32_t yiaddr;    /* 16 */
+  u_int32_t siaddr;    /* 20 */
+  u_int32_t giaddr;    /* 24 */
+  u_int8_t chaddr[16]; /* 28 */
+  u_int8_t sname[64];  /* 44 */
+  u_int8_t file[128];  /* 108 */
+  u_int32_t magic;     /* 236 */
+  u_int8_t options[308];
 } PACK_OFF;
 
 /* http://en.wikipedia.org/wiki/SCTP_packet_structure */
@@ -804,20 +834,12 @@ PACK_ON
 struct sctphdr {
   /* Common Header */
   u_int16_t sport, dport;
-  u_int32_t verification_tag; /* A 32-bit random value created during initialization to distinguish stale packets from a previous connection. */
-  u_int32_t checksum; /*  CRC32c algorithm */
+  u_int32_t verification_tag; /* A 32-bit random value created during
+                                 initialization to distinguish stale packets
+                                 from a previous connection. */
+  u_int32_t checksum;         /*  CRC32c algorithm */
 } PACK_OFF;
 
-#ifdef NTOPNG_PRO
-
-typedef struct {
-  char *host_or_mac;
-  time_t lifetime;
-  UT_hash_handle hh; /* makes this structure hashable */
-} volatile_members_t;
-
-#endif
-
 /*
   NOTE:
   Keep in sync with discover.lua (asset_icons)
@@ -856,9 +878,8 @@ typedef struct {
 } FlowHTTPStats;
 
 typedef struct {
-  u_int8_t num_a, num_ns, num_cname, num_soa,
-    num_ptr, num_mx, num_txt, num_aaaa,
-    num_any, num_other;
+  u_int8_t num_a, num_ns, num_cname, num_soa, num_ptr, num_mx, num_txt,
+      num_aaaa, num_any, num_other;
   u_int8_t num_replies_ok, num_replies_error;
 } FlowDNSStats;
 
@@ -911,17 +932,18 @@ struct ntopngLuaContext {
     /* Partial sends */
     char send_buffer[1600];
     u_int data_not_yet_sent_len; /*
-				    Amount of data that was
-				    not sent mostly due to
-				    socket buffering
-				 */
+                                    Amount of data that was
+                                    not sent mostly due to
+                                    socket buffering
+                                 */
   } live_capture;
 
   /*
      Indicate the time when the vm will be reloaded.
-     This can be used so that Lua scripts running in an infinite-loop fashion, e.g., notifications.lua,
-     can know when to break so they can be reloaded with new configurations.
-     Useful when user scripts change or when recipient configurations change.
+     This can be used so that Lua scripts running in an infinite-loop fashion,
+     e.g., notifications.lua, can know when to break so they can be reloaded
+     with new configurations. Useful when user scripts change or when recipient
+     configurations change.
    */
   time_t next_reload;
   /* Periodic scripts (ThreadedActivity.cpp) */
@@ -981,7 +1003,7 @@ typedef enum {
 /* Keep in sync with hosts_map_utils.lua */
 typedef enum {
   ALL_FLOWS = 0,
-  UNREACHABLE_FLOWS  = 1,
+  UNREACHABLE_FLOWS = 1,
   ALERTED_FLOWS = 2,
   DNS_QUERIES = 3,
   SYN_DISTRIBUTION = 4,
@@ -1035,7 +1057,7 @@ typedef struct {
 } HTTPTranferStats;
 
 typedef struct {
-  lua_State* vm;
+  lua_State *vm;
   time_t last_conn_check;
   struct {
     u_int32_t download, upload;
@@ -1076,7 +1098,8 @@ typedef struct ts_icmp_stats {
 } ts_icmp_stats;
 
 class AlertableEntity;
-typedef void (alertable_callback)(AlertEntity alert_entity_type, AlertableEntity *alertable, void *user_data);
+typedef void(alertable_callback)(AlertEntity alert_entity_type,
+                                 AlertableEntity *alertable, void *user_data);
 
 typedef struct bcast_domain_info {
   bool is_interface_network;
@@ -1132,10 +1155,7 @@ typedef enum {
   map_column_rank
 } mapSortingColumn;
 
-typedef enum {
-  asc = 0,
-  desc
-} sortingOrder;
+typedef enum { asc = 0, desc } sortingOrder;
 
 typedef struct _MapsFilters {
   bool periodicity_or_service;
@@ -1171,7 +1191,7 @@ typedef struct {
     ipAddress ip;
     u_int8_t mac[6];
   } addr;
-  u_int8_t by_mac:1, not_used:7;
+  u_int8_t by_mac : 1, not_used : 7;
 } PeriodicityStatsPeerKey;
 
 typedef struct {
@@ -1181,14 +1201,30 @@ typedef struct {
 } PeriodicityStatsKey;
 
 /* This enum is used to dump the confidences types to the db */
-typedef enum {
-  confidence_guessed = 0,
-  confidence_dpi = 1
-} ndpiConfidence;
+typedef enum { confidence_guessed = 0, confidence_dpi = 1 } ndpiConfidence;
 
 typedef struct {
   u_int32_t bytes_sent;
   u_int32_t bytes_rcvd;
 } InOutTraffic;
 
+typedef struct {
+  u_int64_t bytes_sent;
+  u_int64_t bytes_rcvd;
+  u_int64_t packets_sent;
+  u_int64_t packets_rcvd;
+} RadiusTraffic;
+
+typedef enum {
+  unknown_criteria,
+  application_criteria = 1,
+  client_criteria,
+  server_criteria,
+  client_server_criteria,
+  app_client_server_criteria,
+  info_criteria,
+  client_server_srv_port
+} AnalysisCriteria;
+
+
 #endif /* _NTOP_TYPEDEFS_H_ */
