@@ -19,7 +19,7 @@ local sleep_duration = periodicity * 1000
 for i=1,num_runs do
    local now = os.time()
 
-   if(ntop.isShutdown()) then break end
+   if(ntop.isShuttingDown()) then break end
    
    -- Do the actual processing
    recipients.process_notifications(now, now + periodicity --[[ deadline --]], periodicity)
