@@ -13,7 +13,7 @@ local os_utils = require "os_utils"
 
 sendHTTPContentTypeHeader('text/html')
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.about, { product=info.product })
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.about, { product=info.product })
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
 print("<div class='row'>")
