@@ -25,8 +25,12 @@ local master_ifid = interface.getMasterInterfaceId(ifid)
 local window_info = recording_utils.isDataAvailable(master_ifid, epoch_begin, epoch_end)
 
 if window_info.epoch_begin and window_info.epoch_end then
-  window_info.epoch_begin_formatted = format_utils.formatPastEpochShort(window_info.epoch_begin)
-  window_info.epoch_end_formatted = format_utils.formatPastEpochShort(window_info.epoch_end)
+   window_info.epoch_begin_formatted = format_utils.formatPastEpochShort(window_info.epoch_begin)
+   window_info.epoch_end_formatted = format_utils.formatPastEpochShort(window_info.epoch_end)
+end
+
+if window_info.smart then
+   window_info.info = i18n("traffic_recording.about_to_download_smart")
 end
 
 print(json.encode(window_info))
