@@ -1,5 +1,5 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-23 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -39,7 +39,9 @@ for key, value in pairs(hosts_stats) do
    if(val > threshold) then
 
    if(num > 0) then print(",\n") else print("\n") end
-   res = getResolvedAddress(hostkey2hostinfo(key))
+
+   local hinfo = hostkey2hostinfo(key)
+   name = hostinfo2label(hinfo)
 
    --if(res == nil) then res = "AAA" end
    print("{ \"name\": \"" .. res .. "\", \"size\": " .. (hosts_stats[key]["bytes.sent"]+hosts_stats[key]["bytes.rcvd"]).. "} ")
