@@ -1,17 +1,15 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-23 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
-require "graph_utils"
-require "historical_utils"
+local graph_utils = require "graph_utils"
 
 sendHTTPContentTypeHeader('text/html')
 
-
 ifid = _GET["ifid"]
 direction = _GET["sflow_filter"]
 
@@ -26,7 +24,7 @@ local ago1h  = now - 3600
 local protos = interface.getnDPIProtocols()
 
 if(host == nil) then
-   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> "..i18n("ndpi_page.unable_to_find_host",{host_ip=host_ip}).."</div>")
+   print("<div class=\"alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i> "..i18n("ndpi_page.unable_to_find_host",{host_ip=host_ip}).."</div>")
    return
 end
 
@@ -76,42 +74,39 @@ end
 
 local total = total_sent + total_recv
 
-print("<tr><td>Total</td><td class=\"text-right\">".. secondsToTime(host["total_activity_time"]) .."</td><td class=\"text-right\">" .. bytesToSize(total_sent) .. "</td><td class=\"text-right\">" .. bytesToSize(total_recv) .. "</td>")
+print("<tr><td>Total</td><td class=\"text-end\">".. secondsToTime(host["total_activity_time"]) .."</td><td class=\"text-end\">" .. bytesToSize(total_sent) .. "</td><td class=\"text-end\">" .. bytesToSize(total_recv) .. "</td>")
 
 print("<td>")
-breakdownBar(total_sent, i18n("ndpi_page.sent"), total_recv, i18n("ndpi_page.rcvd"), 0, 100)
+graph_utils.breakdownBar(total_sent, i18n("ndpi_page.sent"), total_recv, i18n("ndpi_page.rcvd"), 0, 100)
 print("</td>\n")
 
-print("<td colspan=2 class=\"text-right\">" ..  bytesToSize(total).. "</td></tr>\n")
+print("<td colspan=2 class=\"text-end\">" ..  bytesToSize(total).. "</td></tr>\n")
 
 for _k in pairsByKeys(vals , desc) do
   k = vals[_k]
 
   if filter_pass(host["ndpi"][k]) then
     print("<tr><td>")
-    fname = getRRDName(ifid, hostinfo2hostkey(host_info), k..".rrd")
-    if(ntop.exists(fname)) then
-      print("<A HREF=\""..ntop.getHttpPrefix().."/lua/host_details.lua?ifid="..ifid.."&"..hostinfo2url(host_info) .. "&page=historical&rrd_file=".. k ..".rrd\">"..k.." "..formatBreed(host["ndpi"][k]["breed"]).."</A>")
-    else
-      print(k.." "..formatBreed(host["ndpi"][k]["breed"]))
-    end
-    
+
+    local host_href = hostinfo2detailshref(host_info, {page = "historical", ts_schema = "host:ndpi", protocol = k}, getCategoryLabel(k).." "..formatBreed(host["ndpi"][k]["breed"]))
+    print(host_href)
+
     t = host["ndpi"][k]["bytes.sent"]+host["ndpi"][k]["bytes.rcvd"]
 
     if((host["ndpi"][k]["bytes.sent"] == 0) and (host["ndpi"][k]["bytes.rcvd"] > 0)) then
-       print(" <i class=\"fa fa-warning fa-lg\" style=\"color: orange;\"></i>")
+       print(" <i class=\"fas fa-exclamation-triangle fa-lg\" style=\"color: orange;\"></i>")
     end
 
     historicalProtoHostHref(getInterfaceId(ifname), host, nil, protos[k], nil)
 
     print('</td>')
-    print("<td class=\"text-right\">" .. secondsToTime(host["ndpi"][k]["duration"]) .. "</td>")
-    print("<td class=\"text-right\">" .. bytesToSize(host["ndpi"][k]["bytes.sent"]) .. "</td><td class=\"text-right\">" .. bytesToSize(host["ndpi"][k]["bytes.rcvd"]) .. "</td>")
+    print("<td class=\"text-end\">" .. secondsToTime(host["ndpi"][k]["duration"]) .. "</td>")
+    print("<td class=\"text-end\">" .. bytesToSize(host["ndpi"][k]["bytes.sent"]) .. "</td><td class=\"text-end\">" .. bytesToSize(host["ndpi"][k]["bytes.rcvd"]) .. "</td>")
 
     print("<td>")
-    breakdownBar(host["ndpi"][k]["bytes.sent"], i18n("ndpi_page.sent"), host["ndpi"][k]["bytes.rcvd"], i18n("ndpi_page.rcvd"), 0, 100)
+    graph_utils.breakdownBar(host["ndpi"][k]["bytes.sent"], i18n("ndpi_page.sent"), host["ndpi"][k]["bytes.rcvd"], i18n("ndpi_page.rcvd"), 0, 100)
     print("</td>\n")
 
-    print("<td class=\"text-right\">" .. bytesToSize(t).. "</td><td class=\"text-right\">" .. round((t * 100)/total, 2).. " %</td></tr>\n")
+    print("<td class=\"text-end\">" .. bytesToSize(t).. "</td><td class=\"text-end\">" .. round((t * 100)/total, 2).. " %</td></tr>\n")
   end
 end
