@@ -35,7 +35,7 @@ local info = ntop.getInfo()
 
 sendHTTPContentTypeHeader('text/html')
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.manage_data)
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.manage_data)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
