@@ -90,6 +90,14 @@ function flow_alert_store:get_column_name(field, is_write, value)
             else                      col = 'IPV4_DST_ADDR' end
          end
       else
+
+         -- Convert columns to tags for those who differ
+         if field == 'proto'            then field = 'l4proto'        end
+         if field == 'l7_cat'           then field = 'l7cat'          end
+         if field == 'l7_proto'         then field = 'l7proto'        end
+         if field == 'l7_master_proto'  then field = 'l7proto_master' end
+         if field == 'flow_risk_bitmap' then field = 'flow_risk'      end
+
          col = historical_flow_utils.get_flow_column_by_tag(field)
       end
 
@@ -199,19 +207,21 @@ function flow_alert_store:insert(alert)
    -- - tstamp (instead of first_seen) is used in select and for visualization as it's in common to all tables
 
    local insert_stmt = string.format("INSERT INTO %s "..
-      "(%salert_id, interface_id, tstamp, tstamp_end, severity, ip_version, cli_ip, srv_ip, cli_port, srv_port, vlan_id, "..
+      "(%salert_id, alert_status, alert_category, interface_id, tstamp, tstamp_end, severity, ip_version, cli_ip, srv_ip, cli_port, srv_port, vlan_id, "..
       "is_cli_attacker, is_cli_victim, is_srv_attacker, is_srv_victim, proto, l7_proto, l7_master_proto, l7_cat, "..
       "cli_name, srv_name, cli_country, srv_country, cli_blacklisted, srv_blacklisted, cli_location, srv_location, "..
       "cli2srv_bytes, srv2cli_bytes, cli2srv_pkts, srv2cli_pkts, first_seen, community_id, score, "..
       "flow_risk_bitmap, alerts_map, cli_host_pool_id, srv_host_pool_id, cli_network, srv_network, probe_ip, input_snmp, output_snmp, "..
       "json, info) "..
-      "VALUES (%s%u, %u, %u, %u, %u, %u, '%s', '%s', %u, %u, %u, %u, %u, %u, %u, %u, %u, %u, %u, '%s', '%s', '%s', "..
+      "VALUES (%s%u, %u, %u, %u, %u, %u, %u, %u, '%s', '%s', %u, %u, %u, %u, %u, %u, %u, %u, %u, %u, %u, '%s', '%s', '%s', "..
       "'%s', %u, %u, %u, %u, %u, %u, %u, %u, %u, '%s', %u, %u, %s'%s', %u, %u, %u, %u, '%s', %u, %u, '%s', '%s'); ",
 
       self:get_write_table_name(),
       extra_columns,
       extra_values,
       alert.alert_id,
+      ternary(alert.acknowledged, alert_consts.alert_status.acknowledged.alert_status_id, 0),
+      alert.alert_category,
       self:_convert_ifid(interface.getId()),
       alert.first_seen,
       alert.tstamp,
@@ -271,7 +281,7 @@ function flow_alert_store:top_l7_proto_historical()
    -- Preserve all the filters currently set
    local where_clause = self:build_where_clause()
 
-   local q = string.format("SELECT l7_proto, count(*) count FROM %s WHERE %s GROUP BY l7_proto ORDER BY count DESC LIMIT %u",
+   local q = string.format("SELECT l7_proto, sum(score) count FROM %s WHERE %s GROUP BY l7_proto ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    local q_res = interface.alert_store_query(q) or {}
 
@@ -289,7 +299,7 @@ function flow_alert_store:top_vlan_historical()
    -- Preserve all the filters currently set
    local where_clause = self:build_where_clause()
 
-   local q = string.format("SELECT vlan_id, count(*) count FROM %s WHERE %s AND vlan_id != 0 GROUP BY vlan_id ORDER BY count DESC LIMIT %u",
+   local q = string.format("SELECT vlan_id, sum(score) count FROM %s WHERE %s AND vlan_id != 0 GROUP BY vlan_id ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    local q_res = interface.alert_store_query(q) or {}
 
@@ -305,10 +315,10 @@ function flow_alert_store:top_cli_ip_historical()
 
    local q
    if ntop.isClickHouseEnabled() then
-      q = string.format("SELECT cli_ip, vlan_id, cli_name, count(*) count FROM %s WHERE %s GROUP BY cli_ip, vlan_id, cli_name ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT cli_ip, vlan_id, cli_name, sum(score) count FROM %s WHERE %s GROUP BY cli_ip, vlan_id, cli_name ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    else
-      q = string.format("SELECT cli_ip, vlan_id, cli_name, count(*) count FROM %s WHERE %s GROUP BY cli_ip ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT cli_ip, vlan_id, cli_name, sum(score) count FROM %s WHERE %s GROUP BY cli_ip ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    end
 
@@ -326,10 +336,10 @@ function flow_alert_store:top_srv_ip_historical()
 
    local q
    if ntop.isClickHouseEnabled() then
-      q = string.format("SELECT srv_ip, vlan_id, srv_name, count(*) count FROM %s WHERE %s GROUP BY srv_ip, vlan_id, srv_name ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT srv_ip, vlan_id, srv_name, sum(score) count FROM %s WHERE %s GROUP BY srv_ip, vlan_id, srv_name ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    else
-      q = string.format("SELECT srv_ip, vlan_id, srv_name, count(*) count FROM %s WHERE %s GROUP BY srv_ip ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT srv_ip, vlan_id, srv_name, sum(score) count FROM %s WHERE %s GROUP BY srv_ip ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    end
 
@@ -340,6 +350,29 @@ end
 
 -- ##############################################
 
+--@brief Performs a query for the top domain named hosts for suspicious_dga_domain alerts by alert count
+function flow_alert_store:top_srv_ip_domain()
+   -- Preserve all the filters currently set
+   local where_clause = self:build_where_clause().." AND alert_id = 47 "
+   local field_to_search = self:get_column_name('json', false)
+   local q = nil
+   local q_res = {}
+   if ntop.isClickHouseEnabled() then
+      
+      q = string.format("SELECT '.' || arrayStringConcat(arraySlice(splitByString('.',"..  string.format('JSON_VALUE(%s, \'$.%s\')', field_to_search, "proto.tls.client_requested_server_name")
+.."),-2,2),'.') as domain_name_trunc_dot, vlan_id, '*.' || arrayStringConcat(arraySlice(splitByString('.',"..  string.format('JSON_VALUE(%s, \'$.%s\')', field_to_search, "proto.tls.client_requested_server_name")
+.."),-2,2),'.') as domain_name_trunc_star, sum(score) count FROM %s WHERE %s GROUP BY vlan_id, '*.' || arrayStringConcat(arraySlice(splitByString('.',"..  string.format('JSON_VALUE(%s, \'$.%s\')', field_to_search, "proto.tls.client_requested_server_name")
+.."),-2,2),'.'), '.' || arrayStringConcat(arraySlice(splitByString('.',"..  string.format('JSON_VALUE(%s, \'$.%s\')', field_to_search, "proto.tls.client_requested_server_name")
+.."),-2,2),'.') ORDER BY count DESC LIMIT %u",self:get_table_name(), where_clause, self._top_limit)
+   
+      q_res = interface.alert_store_query(q)
+   end
+
+   return q_res
+end
+
+-- ##############################################
+
 --@brief Merge top clients and top servers to build a top hosts 
 function flow_alert_store:top_ip_merge(top_cli_ip, top_srv_ip)
    local all_ip = {}
@@ -387,10 +420,10 @@ function flow_alert_store:top_cli_network_historical()
 
    local q
    if ntop.isClickHouseEnabled() then
-      q = string.format("SELECT cli_network, count(*) count FROM %s WHERE %s GROUP BY cli_network ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT cli_network, sum(score) count FROM %s WHERE %s GROUP BY cli_network ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    else
-      q = string.format("SELECT cli_network, count(*) count FROM %s WHERE %s GROUP BY cli_network ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT cli_network, sum(score) count FROM %s WHERE %s GROUP BY cli_network ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    end
 
@@ -408,10 +441,10 @@ function flow_alert_store:top_srv_network_historical()
 
    local q
    if ntop.isClickHouseEnabled() then
-      q = string.format("SELECT srv_network, count(*) count FROM %s WHERE %s GROUP BY srv_network ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT srv_network, sum(score) count FROM %s WHERE %s GROUP BY srv_network ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    else
-      q = string.format("SELECT srv_network, count(*) count FROM %s WHERE %s GROUP BY srv_network ORDER BY count DESC LIMIT %u",
+      q = string.format("SELECT srv_network, sum(score) count FROM %s WHERE %s GROUP BY srv_network ORDER BY count DESC LIMIT %u",
          self:get_table_name(), where_clause, self._top_limit)
    end
 
@@ -461,6 +494,7 @@ function flow_alert_store:_get_additional_stats()
    stats.top.srv_network = self:top_srv_network_historical()
    stats.top.network = self:top_network_merge(stats.top.cli_network, stats.top.srv_network)
    stats.top.vlan = self:top_vlan_historical()
+   stats.top.dga_domain = self:top_srv_ip_domain()
    return stats
 end
 
@@ -515,11 +549,16 @@ function flow_alert_store:_add_additional_request_filters()
    
    local error_code = _GET["l7_error_id"]
    local confidence = _GET["confidence"]
+   local community_id = _GET["community_id"]
+   local ja3_client = _GET["ja3_client"]
+   local ja3_server = _GET["ja3_server"]
+   local alert_domain = _GET["alert_domain"]
    
    self:format_traffic_direction(_GET["traffic_direction"])
    
    -- Filter out flows with no alert
-   self:add_filter_condition_list('alert_id', "0"..tag_utils.SEPARATOR.."neq", 'number')
+   -- Any reason we need this?
+   -- self:add_filter_condition_list('alert_id', "0"..tag_utils.SEPARATOR.."neq", 'number')
 
    self:add_filter_condition_list('vlan_id', vlan_id, 'number')
    self:add_filter_condition_list('ip_version', ip_version)
@@ -545,9 +584,14 @@ function flow_alert_store:_add_additional_request_filters()
    self:add_filter_condition_list('input_snmp', input_snmp)
    self:add_filter_condition_list('output_snmp', output_snmp)
    self:add_filter_condition_list('snmp_interface', snmp_interface)
+   self:add_filter_condition_list('community_id', community_id)
 
+   self:add_filter_condition_list(self:format_query_json_value('proto.ja3.server_hash'), ja3_server, 'string')
+   self:add_filter_condition_list(self:format_query_json_value('proto.ja3.client_hash'), ja3_client, 'string')
    self:add_filter_condition_list(self:format_query_json_value('proto.l7_error_code'), error_code, 'string')
    self:add_filter_condition_list(self:format_query_json_value('proto.confidence'), confidence, 'string')
+   self:add_filter_condition_list(self:format_query_json_value('proto.tls.client_requested_server_name'), alert_domain, 'string')
+
 end
 
 -- ##############################################
@@ -578,7 +622,11 @@ function flow_alert_store:_get_additional_available_filters()
 
       l7_error_id       = tag_utils.defined_tags.l7_error_id,
       confidence        = tag_utils.defined_tags.confidence,
+      community_id      = tag_utils.defined_tags.community_id,
+      ja3_client        = tag_utils.defined_tags.ja3_client,
+      ja3_server        = tag_utils.defined_tags.ja3_server,
       traffic_direction = tag_utils.defined_tags.traffic_direction,
+      alert_domain      = tag_utils.defined_tags.alert_domain,
 
       probe_ip = tag_utils.defined_tags.probe_ip,
       input_snmp = tag_utils.defined_tags.input_snmp,
@@ -598,8 +646,15 @@ local RNAME = {
    FLOW_RELATED_INFO = { name = "flow_related_info", export = true },
    MSG = { name = "msg", export = true, elements = {"name", "value", "description"}},
    FLOW = { name = "flow", export = true, elements = {"srv_ip.label", "srv_ip.value", "srv_port", "cli_ip.label", "cli_ip.value", "cli_port"}},
-   
+
    VLAN_ID = { name = "vlan_id", export = true},
+   CLI_IP = { name = "cli_ip", export = false},
+   SRV_IP = { name = "srv_ip", export = false},
+   CLI_PORT = { name = "cli_port", export = false},
+   SRV_PORT = { name = "srv_port", export = false},
+   
+   TRAFFIC = { name = "total_bytes", export = false},
+   
    PROTO = { name = "proto", export = true},
    L7_PROTO = { name = "l7_proto", export = true},
    LINK_TO_PAST_FLOWS = { name = "link_to_past_flows", export = false},
@@ -640,20 +695,26 @@ function flow_alert_store:format_record(value, no_html)
    local record = self:format_json_record_common(value, alert_entities.flow.entity_id, no_html)
    local alert_info = alert_utils.getAlertInfo(value)
    local alert_name = alert_consts.alertTypeLabel(tonumber(value["alert_id"]), true --[[ no_html --]], alert_entities.flow.entity_id)
-   local alert_risk = ntop.getFlowAlertRisk(tonumber(value.alert_id))
-   local l4_protocol = l4_proto_to_string(value["proto"])
-   local l7_protocol =  interface.getnDPIFullProtoName(tonumber(value["l7_master_proto"]), tonumber(value["l7_proto"]))
    local show_cli_port = (value["cli_port"] ~= '' and value["cli_port"] ~= '0')
    local show_srv_port = (value["srv_port"] ~= '' and value["srv_port"] ~= '0') 
    local msg = alert_utils.formatFlowAlertMessage(interface.getId(), value, alert_info)
    local active_url = ""
    local attacker = ""
    local victim = ""
+
+   local alert_json = {}
+   if not isEmptyString(value.json) then
+      alert_json = json.decode(value.json) or {}
+   end
+
    -- Add link to active flow
-   local alert_json = json.decode(value.json)
-  
    local flow_related_info = addExtraFlowInfo(alert_json, value)
 
+   local alert_risk
+   if tonumber(value.alert_id) then
+      alert_risk = ntop.getFlowAlertRisk(tonumber(value.alert_id))
+   end
+
    -- TLS IssuerDN
    local flow_tls_issuerdn = nil
    if alert_risk and alert_risk > 0 and 
@@ -679,7 +740,9 @@ function flow_alert_store:format_record(value, no_html)
    local other_alerts_by_score = {} -- Table used to keep messages ordered by score
    local additional_alerts = {}
   
-   other_alerts_by_score, additional_alerts = alert_utils.format_other_alerts(value.alerts_map, value['alert_id'])
+   if value.alerts_map then
+      other_alerts_by_score, additional_alerts = alert_utils.format_other_alerts(value.alerts_map, value['alert_id'])
+   end
 
    -- Print additional issues, sorted by score
    record[RNAME.ADDITIONAL_ALERTS.name] = ''
@@ -698,10 +761,6 @@ function flow_alert_store:format_record(value, no_html)
       end
    end
 
-   -- Handle VLAN as a separate field
-   local cli_ip = value["cli_ip"]
-   local srv_ip = value["srv_ip"]
-
    local shorten_msg
 
    record[RNAME.ADDITIONAL_ALERTS.name] = {
@@ -717,7 +776,8 @@ function flow_alert_store:format_record(value, no_html)
          shorten_descr = shorten_msg,
       }
    end
-   local proto = string.lower(interface.getnDPIProtoName(tonumber(value["l7_master_proto"])))
+
+   -- local proto = string.lower(interface.getnDPIProtoName(tonumber(value["l7_master_proto"])))
 
    local flow_server_name = getExtraFlowInfoServerName(alert_json)
    local flow_domain
@@ -726,9 +786,9 @@ function flow_alert_store:format_record(value, no_html)
    end
 
    record[RNAME.INFO.name] = {
-     descr = format_external_link(value["info"], value["info"], no_html, proto),
-     value = flow_domain, -- Domain name used for alert exclusion
-     issuerdn = flow_tls_issuerdn, -- IssuerDN used for alert exclusion
+      label = value["info"],
+      value = value["info"], 
+      issuerdn = flow_tls_issuerdn, -- IssuerDN used for alert exclusion
    }
 
    record[RNAME.FLOW_RELATED_INFO.name] = {
@@ -786,9 +846,11 @@ function flow_alert_store:format_record(value, no_html)
 
    -- Format Client  
  
+   local cli_ip = value["cli_ip"]
+
    local reference_html = "" 
-   if not no_html then
-      reference_html = hostinfo2detailshref({ip = value["cli_ip"], value["vlan_id"]}, nil, href_icon, "", true, nil, false)
+   if not isEmptyString(cli_ip) and not no_html then
+      reference_html = hostinfo2detailshref({ip = cli_ip, value["vlan_id"]}, nil, href_icon, "", true, nil, false)
       if reference_html == href_icon then
 	 reference_html = ""
       end
@@ -797,47 +859,59 @@ function flow_alert_store:format_record(value, no_html)
    -- In case no country is found, let's check if the host is in memory and retrieve country info
    local country = value["cli_country"]
 
-   if isEmptyString(country) or country == "nil" then
+   if (isEmptyString(country) or country == "nil") and not isEmptyString(cli_ip) then
       local host_info = interface.getHostMinInfo(cli_ip)
       if host_info then
          country = host_info["country"] or ""
       end
    end
+
+   record["community_id"] = {
+      value = value["community_id"],
+      name = value["community_id"]
+   }
   
    local flow_cli_ip = {
-      value = cli_ip,
-      label = cli_ip,
+      value = cli_ip or "",
+      ip = cli_ip or "",
+      label = cli_ip or "",
       reference = reference_html,
       country = country,
       blacklisted = value["cli_blacklisted"]
    }
 
-   if no_html then
-      flow_cli_ip["label"] = cli_name_long
-   else
-      if not isEmptyString(value["cli_name"]) and value["cli_name"] ~= flow_cli_ip["value"] then
-         flow_cli_ip["name"] = value["cli_name"]
-      end
+   if not isEmptyString(value["cli_name"]) and value["cli_name"] ~= flow_cli_ip["value"] then
+      flow_cli_ip["name"] = value["cli_name"]
+   end
+
+   if not isEmptyString(cli_ip) then
+      local label = hostinfo2label(self:_alert2hostinfo(value, 
+         true --[[ As client --]]), 
+         false --[[ Show VLAN --]], 
+         false --[[ Shorten --]], 
+         true --[[ Skip Resolution ]])
 
       -- Shortened label if necessary for UI purposes
-      flow_cli_ip["label"] = hostinfo2label(self:_alert2hostinfo(value, true --[[ As client --]]), false --[[ Show VLAN --]], false --[[ Shorten --]])
-      flow_cli_ip["label_long"] = hostinfo2label(self:_alert2hostinfo(value, true --[[ As client --]]), false --[[ Show VLAN --]], false)
+      flow_cli_ip["label"] = label
+      flow_cli_ip["label_long"] = label
    end
 
    -- Format Server
 
+   local srv_ip = value["srv_ip"]
+
    reference_html = ""
-   if not no_html then
-      reference_html = hostinfo2detailshref({ip = value["srv_ip"], vlan = value["vlan_id"]}, nil, href_icon, "", true)
+   if not no_html and not isEmptyString(srv_ip) then
+      reference_html = hostinfo2detailshref({ip = srv_ip, vlan = value["vlan_id"]}, nil, href_icon, "", true)
       if reference_html == href_icon then
-	 reference_html = ""
+         reference_html = ""
       end
    end
 
    -- In case no country is found, let's check if the host is in memory and retrieve country info
    country = value["srv_country"]
 
-   if isEmptyString(country) or country == "nil" then
+   if (isEmptyString(country) or country == "nil") and not isEmptyString(srv_ip) then
       local host_info = interface.getHostMinInfo(srv_ip)
       if host_info then
          country = host_info["country"] or ""
@@ -845,29 +919,36 @@ function flow_alert_store:format_record(value, no_html)
    end
 
    local flow_srv_ip = {
-      value = srv_ip,
-      label = srv_ip,
+      value = srv_ip or "",
+      ip = srv_ip or "",
+      label = srv_ip or "",
       reference = reference_html,
       country = country,
       blacklisted = value["srv_blacklisted"]
    }
 
-   if no_html then
-      flow_srv_ip["label"] = srv_name_long
-   else
-      if not isEmptyString(value["srv_name"]) and value["srv_name"] ~= flow_srv_ip["value"] then
-         flow_srv_ip["name"] = value["srv_name"]
-      end
-      
+   if not isEmptyString(value["srv_name"]) and value["srv_name"] ~= flow_srv_ip["value"] then
+      flow_srv_ip["name"] = value["srv_name"]
+   end
+   
+   if not isEmptyString(srv_ip) then
+      local label = hostinfo2label(self:_alert2hostinfo(value, 
+         false --[[ As server --]]), 
+         false --[[ Show VLAN --]], 
+         false --[[ Shorten --]], 
+         true --[[ Skip Resolution ]])
+
       -- Shortened label if necessary for UI purposes
-      flow_srv_ip["label"] = hostinfo2label(self:_alert2hostinfo(value, false --[[ As server --]]), false --[[ Show VLAN --]], false --[[ Shorten --]])
-      flow_srv_ip["label_long"] = hostinfo2label(self:_alert2hostinfo(value, false --[[ As server --]]), false --[[ Show VLAN --]], false)
+      flow_srv_ip["label"] = label
+      flow_srv_ip["label_long"] = label
    end
 
-   local flow_cli_port = value["cli_port"]
-   local flow_srv_port = value["srv_port"]
+   local vlan = {
+      label = "",
+      title = "",
+      value = 0
+   }
 
-   local vlan 
    if value["vlan_id"] and tonumber(value["vlan_id"]) ~= 0 then
       vlan = {
          label = getFullVlanName(value["vlan_id"], true --[[ Compact --]]),
@@ -876,19 +957,38 @@ function flow_alert_store:format_record(value, no_html)
       }
    end
 
+   local flow_cli_port = {
+      value = value["cli_port"],
+   }
+   local flow_srv_port = {
+      value = value["srv_port"],
+   }
+
+   -- Used to render custom queries (compatible with historical flows columns definition)
+   record[RNAME.CLI_IP.name] = flow_cli_ip
+   record[RNAME.SRV_IP.name] = flow_srv_ip
+   record[RNAME.CLI_PORT.name] = flow_cli_port
+   record[RNAME.SRV_PORT.name] = flow_srv_port
+   record[RNAME.VLAN_ID.name] = vlan
+
+   -- Used to render the flow column in raw alerts
    record[RNAME.FLOW.name] = {
       vlan = vlan,
       cli_ip = flow_cli_ip,
       srv_ip = flow_srv_ip,
-      cli_port = flow_cli_port,
-      srv_port = flow_srv_port,
+      cli_port = value["cli_port"],
+      srv_port = value["srv_port"],
       active_url = active_url,
    }
 
-   record[RNAME.VLAN_ID.name] = value["vlan_id"]
+   local l4_protocol
+   if not isEmptyString(value["proto"]) then
+      l4_protocol = l4_proto_to_string(value["proto"])
+   end
+
    record[RNAME.PROTO.name] = {
-      value = value["proto"],
-      label = l4_protocol
+      value = value["proto"] or "",
+      label = l4_protocol or ""
    }
 
    if value["is_cli_victim"]   == "1" then record["cli_role"] = { value = 'victim',   label = i18n("victim"),   tag_label = i18n("victim") } end
@@ -896,23 +996,44 @@ function flow_alert_store:format_record(value, no_html)
    if value["is_srv_victim"]   == "1" then record["srv_role"] = { value = 'victim',   label = i18n("victim"),   tag_label = i18n("victim") } end
    if value["is_srv_attacker"] == "1" then record["srv_role"] = { value = 'attacker', label = i18n("attacker"), tag_label = i18n("attacker") } end
 
+   local l7_protocol
+   if tonumber(value["l7_master_proto"]) and tonumber(value["l7_proto"]) then
+      l7_protocol = interface.getnDPIFullProtoName(tonumber(value["l7_master_proto"]), tonumber(value["l7_proto"]))
+   end
+
    -- Check the two labels, otherwise an ICMP:ICMP label could be possible
    local proto_label = l7_protocol
 
-   if l4_protocol ~= l7_protocol then
-    proto_label = l4_protocol..":"..l7_protocol
+   if l4_protocol and l7_protocol and l4_protocol ~= l7_protocol then
+      proto_label = l4_protocol..":"..l7_protocol
    end
 
    record[RNAME.L7_PROTO.name] = {
       value = ternary(tonumber(value["l7_proto"]) ~= 0, value["l7_proto"], value["l7_master_proto"]),
-      l4_label = l4_protocol,
-      l7_label = l7_protocol,
-      label = proto_label,
+      l4_label = l4_protocol or "",
+      l7_label = l7_protocol or "",
+      label = proto_label or "",
       confidence = format_confidence_from_json(value)
    }
 
+   local traffic_stats = {}
+   if value["cli2srv_bytes"] then
+      traffic_stats.bytes_sent = tonumber(value["cli2srv_bytes"])
+   end
+   if value["srv2cli_bytes"] then
+      traffic_stats.bytes_rcvd = tonumber(value["srv2cli_bytes"])
+   end
+   if value["total_bytes"] then
+      traffic_stats.total_bytes = tonumber(value["total_bytes"])
+   end
+   if value["srv2cli_pkts"] and value["cli2srv_pkts"] then
+      traffic_stats.total_packets = tonumber(value["srv2cli_pkts"]) + tonumber(value["cli2srv_pkts"])
+   end
+   record[RNAME.TRAFFIC.name] = traffic_stats
+
    -- Add link to historical flow
-   if ntop.isEnterpriseM() and hasClickHouseSupport() and not no_html then
+   if ntop.isEnterpriseM() and hasClickHouseSupport() and not no_html 
+      and tonumber(value["tstamp"]) and tonumber(value["tstamp_end"]) then
       local op_suffix = tag_utils.SEPARATOR .. 'eq'
       local href = string.format('%s/lua/pro/db_search.lua?epoch_begin=%u&epoch_end=%u&cli_ip=%s%s&srv_ip=%s%s&cli_port=%s%s&srv_port=%s%s&l4proto=%s%s',
          ntop.getHttpPrefix(), 
@@ -922,25 +1043,56 @@ function flow_alert_store:format_record(value, no_html)
          value["srv_ip"], op_suffix,
          ternary(show_cli_port, tostring(value["cli_port"]), ''), op_suffix,
          ternary(show_srv_port, tostring(value["srv_port"]), ''), op_suffix,
-         l4_protocol, op_suffix)
+         l4_protocol or "", op_suffix)
+
+      if vlan then
+        href = href .. string.format('&vlan_id=%s%s', vlan.value, op_suffix)
+      end
 
       record[RNAME.LINK_TO_PAST_FLOWS.name] = href
    end
 
-   -- Add BPF filter
+   -- Add BPF filter (for PCAP extractions)
+   -- and Tag filters (e.g. to jump from custom queries to raw alerts)
+
+   record['filter'] = {}
+
    local rules = {}
-   rules[#rules+1] = 'host ' .. value["cli_ip"]
-   rules[#rules+1] = 'host ' .. value["srv_ip"]
-   if value["cli_port"] and tonumber(value["cli_port"]) > 0 then
+   local filters = {}
+   local op_suffix = 'eq'
+
+   if not isEmptyString(value["alert_id"]) and tonumber(value["alert_id"]) > 0 then
+      filters[#filters+1] = { id = "alert_id", value = value["alert_id"], op = op_suffix }
+   end
+   if not isEmptyString(value["vlan_id"]) and tonumber(value["vlan_id"]) > 0 then
+      filters[#filters+1] = { id = "vlan_id", value = value["vlan_id"], op = op_suffix }
+   end
+   if not isEmptyString(value["cli_ip"]) then
+      rules[#rules+1] = 'host ' .. value["cli_ip"]
+      filters[#filters+1] = { id = "cli_ip", value = value["cli_ip"], op = op_suffix }
+   end
+   if not isEmptyString(value["srv_ip"]) then
+      rules[#rules+1] = 'host ' .. value["srv_ip"]
+      filters[#filters+1] = { id = "srv_ip", value = value["srv_ip"], op = op_suffix }
+   end
+   if not isEmptyString(value["cli_port"]) and tonumber(value["cli_port"]) > 0 then
       rules[#rules+1] = 'port ' .. tostring(value["cli_port"])
+      filters[#filters+1] = { id = "cli_port", value = value["cli_port"], op = op_suffix }
+   end
+   if not isEmptyString(value["srv_port"]) and tonumber(value["srv_port"]) > 0 then
       rules[#rules+1] = 'port ' .. tostring(value["srv_port"])
+      filters[#filters+1] = { id = "srv_port", value = value["srv_port"], op = op_suffix }
+   end
+   if not isEmptyString(value["info"]) then
+      filters[#filters+1] = { id = "info", value = value["info"], op = op_suffix }
    end
 
-   record['filter'] = {
-      epoch_begin = tonumber(value["tstamp"]), 
-      epoch_end = tonumber(value["tstamp_end"]) + 1,
-      bpf = table.concat(rules, " and "),
-   }
+   if #rules > 0 and tonumber(value["tstamp"]) and tonumber(value["tstamp_end"]) then
+      record['filter'].epoch_begin = tonumber(value["tstamp"])
+      record['filter'].epoch_end = tonumber(value["tstamp_end"]) + 1
+      record['filter'].bpf = table.concat(rules, " and ")
+   end
+   record['filter'].tag_filters = filters
 
    local probe_ip = ''
    local probe_label = ''
