@@ -11,10 +11,12 @@ package.path = dirs.installdir .. "/scripts/lua/modules/notifications/?.lua;" ..
 
 local json = require("dkjson")
 local alert_severities = require "alert_severities"
+local alert_entities = require "alert_entities"
 local alert_consts = require("alert_consts")
 local os_utils = require("os_utils")
 local recipients = require "recipients"
 local pools_alert_utils = require "pools_alert_utils"
+local recording_utils = require "recording_utils"
 
 local do_trace = false
 
@@ -119,10 +121,10 @@ end
 
 -- ##############################################
 
-function alerts_api.addAlertGenerationInfo(alert_json, current_script)
-  if alert_json and current_script then
+function alerts_api.addAlertGenerationInfo(alert_type_params, current_script)
+  if alert_type_params and current_script then
     -- Add information about the script who generated this alert
-    alert_json.alert_generation = {
+    alert_type_params.alert_generation = {
       script_key = current_script.key,
       subdir = current_script.subdir,
     }
@@ -133,18 +135,50 @@ function alerts_api.addAlertGenerationInfo(alert_json, current_script)
   end
 end
 
-local function addAlertGenerationInfo(alert_json)
-  alerts_api.addAlertGenerationInfo(alert_json, current_script)
+local function addAlertGenerationInfo(alert_type_params)
+  alerts_api.addAlertGenerationInfo(alert_type_params, current_script)
 end
 
 -- ##############################################
 
 --! @brief Adds pool information to the alert
 --! @param entity_info data returned by one of the entity_info building functions
-local function addAlertPoolInfo(entity_info, alert_json)
+local function addAlertPoolAndNetworkInfo(entity_info, alert_json)
+   -- Add Pool ID
    if alert_json then
       alert_json.host_pool_id = pools_alert_utils.get_host_pool_id(entity_info)
    end
+
+   -- Add Local Network ID
+   if entity_info.alert_entity == alert_entities.host and
+      entity_info.entity_val then
+      local network_id = ntop.getAddressNetwork(entity_info.entity_val)
+      alert_json.network = network_id
+   end
+end
+
+-- ##############################################
+
+--! @brief Push filter matching the alert to Smart Recording if enabled
+--! See also Host::enqueueAlertToRecipients for alerts triggered from C++
+--! @param entity_info data returned by one of the entity_info building functions
+local function pushSmartRecordingFilter(entity_info, ifid)
+   if entity_info.alert_entity == alert_entities.host and 
+      recording_utils.isSmartEnabled(ifid) then
+
+      local instance = recording_utils.getN2diskInstanceName(ifid)
+      local ip = entity_info.entity_val
+
+      if not isEmptyString(instance) and
+         not isEmptyString(ip) then
+
+         local filter = string.format("%s", ip)
+
+         local key = string.format("n2disk.%s.filter.host.%s", instance, filter)
+         local expiration = 30*60 -- 30 min
+         ntop.setCache(key, "1", expiration)
+      end
+   end
 end
 
 -- ##############################################
@@ -190,9 +224,12 @@ function alerts_api.store(entity_info, type_info, when)
     json = alert_json,
   }
 
-  addAlertPoolInfo(entity_info, alert_to_store)
+  addAlertPoolAndNetworkInfo(entity_info, alert_to_store)
+
   recipients.dispatch_notification(alert_to_store, current_script)
 
+  pushSmartRecordingFilter(entity_info, ifid)
+
   return(true)
 end
 
@@ -273,6 +310,7 @@ function alerts_api.trigger(entity_info, type_info, when, cur_alerts)
   addAlertGenerationInfo(type_info.alert_type_params)
 
   if(cur_alerts and already_triggered(cur_alerts, type_info.alert_type.alert_key, granularity_sec, subtype, true) == true) then
+     --tprint("Already triggered")
      -- Alert does not belong to an exclusion filter and it is already triggered. There's nothing to do, just return.
      return true
   end
@@ -306,10 +344,10 @@ function alerts_api.trigger(entity_info, type_info, when, cur_alerts)
   end
 
   if(triggered == nil) then
-    --debug_print("Alert not triggered (already triggered?) @ "..granularity_sec.."] ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
+    --tprint("Alert not triggered (already triggered?) @ "..granularity_sec.."] ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
     return(false)
   else
-    --debug_print("Alert triggered @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
+    --tprint("Alert triggered @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
   end
 
   triggered.ifid = ifid
@@ -324,10 +362,13 @@ function alerts_api.trigger(entity_info, type_info, when, cur_alerts)
 
     debug_print("Sending notification for alert " .. entity_info.entity_val)
 
-    addAlertPoolInfo(entity_info, triggered)
+    addAlertPoolAndNetworkInfo(entity_info, triggered)
+
     recipients.dispatch_notification(triggered, current_script)
     mark_trigger_notified(triggered)
 
+    pushSmartRecordingFilter(entity_info, ifid)
+
   else
     debug_print("Alert already notified for " .. entity_info.entity_val)
   end
@@ -355,7 +396,8 @@ function alerts_api.release(entity_info, type_info, when, cur_alerts)
   local subtype = type_info.subtype or ""
 
   if(cur_alerts and (not already_triggered(cur_alerts, type_info.alert_type.alert_key, granularity_sec, subtype, true))) then
-     return(true)
+    --tprint("Alert not triggered @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
+    return(true)
   end
 
   when = when or os.time()
@@ -366,36 +408,40 @@ function alerts_api.release(entity_info, type_info, when, cur_alerts)
  
   if(entity_info.alert_entity.entity_id == alert_consts.alertEntity("interface")) then
      if(interface.checkContext(entity_info.entity_val) == false) then
-	alertErrorTraceback("Invalid interface entity detected "..entity_info.alert_entity.entity_id)
+	alertErrorTraceback("Invalid interface context detected for entity id "..entity_info.alert_entity.entity_id)
 	tprint(entity_info)
 	return(false)
      else
 	released = interface.releaseTriggeredAlert(table.unpack(params))
      end
+
   elseif(entity_info.alert_entity.entity_id == alert_consts.alertEntity("network")) then
      if(network.checkContext(entity_info.entity_val) == false) then
-	alertErrorTraceback("Invalid network entity detected "..entity_info.alert_entity.entity_id)
+	alertErrorTraceback("Invalid network context detected for entity id "..entity_info.alert_entity.entity_id)
 	tprint(entity_info)
 	return(false)
      else 
 	released = network.releaseTriggeredAlert(table.unpack(params))
      end
+
   else
     released = interface.releaseExternalAlert(entity_info.alert_entity.entity_id, entity_info.entity_val, table.unpack(params))
   end
 
   if(released == nil) then
-    --debug_print("Alert not released (not triggered?) @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
+    --tprint("Alert not released (not triggered?) @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n")
     return(false)
   else
-    --debug_print("Alert released @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n") 
+    --tprint("Alert released @ "..granularity_sec.." ".. entity_info.entity_val .."@"..type_info.alert_type.i18n_title..":".. subtype .. "\n") 
   end
 
   released.ifid = ifid
   released.action = "release"
 
-  addAlertPoolInfo(entity_info, released)
+  addAlertPoolAndNetworkInfo(entity_info, released)
+
   mark_release_notified(released)
+
   recipients.dispatch_notification(released, current_script)
 
   return(true)
@@ -403,13 +449,20 @@ end
 
 -- ##############################################
 
+function alerts_api.releaseAllAlerts()
+  local alerts = interface.getEngagedAlerts()
+  alerts_api.releaseEntityAlerts(nil, alerts)
+end
+
+-- ##############################################
+
 -- Convenient method to release multiple alerts on an entity
 function alerts_api.releaseEntityAlerts(entity_info, alerts)
   if(alerts == nil) then
     alerts = interface.getEngagedAlerts(entity_info.alert_entity.entity_id, entity_info.entity_val)
   end
 
-  for _, cur_alert in pairs(alerts) do
+  for _, cur_alert in ipairs(alerts) do
      -- NOTE: do not pass alerts here as a parameters as deleting items while
      -- does not work in lua
 
@@ -423,8 +476,15 @@ function alerts_api.releaseEntityAlerts(entity_info, alerts)
      cur_alert_instance:set_score(cur_alert.score)
      cur_alert_instance:set_subtype(cur_alert.subtype)
      cur_alert_instance:set_granularity(alert_consts.sec2granularity(cur_alert.granularity))
+     local entity = entity_info
+     if (entity_info == nil) then
+        entity = {
+          alert_entity = alert_consts.alertEntityById(cur_alert.entity_id),
+          entity_val = cur_alert.entity_val,
+        }
+     end
 
-     cur_alert_instance:release(entity_info)
+     cur_alert_instance:release(entity)
   end
 end
 
@@ -678,10 +738,6 @@ end
 
 -- ##############################################
 
-function alerts_api.host_delta_val(metric_name, granularity, curr_val, skip_first)
-  return(delta_val(host --[[ the host Lua reg ]], metric_name, granularity, curr_val, skip_first))
-end
-
 function alerts_api.interface_delta_val(metric_name, granularity, curr_val, skip_first)
   return(delta_val(interface --[[ the interface Lua reg ]], metric_name, granularity, curr_val, skip_first))
 end
