@@ -20,7 +20,6 @@ dirs = ntop.getDirs()
 
 package.path = dirs.installdir .. "/scripts/lua/modules/i18n/?.lua;" .. package.path
 package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/?.lua;" .. package.path
-package.path = dirs.installdir .. "/scripts/lua/modules/flow_dbms/?.lua;" .. package.path
 package.path = dirs.installdir .. "/scripts/lua/modules/pools/?.lua;" .. package.path
 
 require "lua_trace"
@@ -311,7 +310,8 @@ end
 function hasClickHouseSupport()
    local auth = require "auth"
 
-   if not ntop.isPro() or ntop.isWindows() then
+   if not (ntop.isPro() or ntop.isnEdgeEnterprise())
+      or ntop.isWindows() then
       return false
    end
 
@@ -339,13 +339,12 @@ function interfaceHasClickHouseSupport()
    return(hasClickHouseSupport() and ntop.getPrefs()["is_dump_flows_to_clickhouse_enabled"])
 end
 
---for _key, _value in pairsByKeys(vals, rev) do
---   print(_key .. "=" .. _value .. "\n")
---end
-
 -- ##############################################
 
 function truncate(x)
+   if(x == nil) then
+      tprint(debug.traceback())
+   end
    return x<0 and math.ceil(x) or math.floor(x)
 end
 
@@ -781,6 +780,9 @@ end
 -- ##############################################
 
 function splitNetworkPrefix(net)
+   if not net then
+      tprint(debug.traceback())
+   end
    local prefix = tonumber(net:match("/(.+)"))
    local address = net:gsub("/.+","")
    return address, prefix
@@ -858,14 +860,14 @@ local function label2formattedlabel(alt_name, host_info, show_vlan, shorten_len)
 
       -- Special shorting function for IP addresses
       if res ~= ip then
-	 if shorten_len == false then
-	    -- Don't touch the string, requested as-is without shortening
-	 elseif tonumber(shorten_len) then
-	    -- Shorten according to the specified length
-	    res = shortenString(res, shorten_len)
-	 else
-	    -- Use the default system-wide setting for the shortening
-	    res = shortenString(res, shorten_len)
+         if (not shorten_len) or (shorten_len == false) then
+            -- Don't touch the string, requested as-is without shortening
+         elseif tonumber(shorten_len) then
+            -- Shorten according to the specified length
+            res = shortenString(res, shorten_len)
+         else
+            -- Use the default system-wide setting for the shortening
+            res = shortenString(res)
          end
       end
 
@@ -891,7 +893,7 @@ end
 
 -- Attempt at retrieving an host label from an host_info, using local caches and DNS resolution.
 -- This can be more expensive if compared to only using information found inside host_info.
-local function hostinfo2label_resolved(host_info, show_vlan, shorten_len)
+local function hostinfo2label_resolved(host_info, show_vlan, shorten_len, skip_resolution)
    local ip = host_info["ip"] or host_info["host"]
    local res
 
@@ -901,15 +903,16 @@ local function hostinfo2label_resolved(host_info, show_vlan, shorten_len)
       res = getHostAltName(host_info["mac"])
    end
 
-   if isEmptyString(res) then
+   -- In case no resolution is requested, directly skip this part
+   if (isEmptyString(res)) and (not skip_resolution) then
       -- Try and get the resolved name
       res = ntop.getResolvedName(ip)
 
       if not isEmptyString(res) then
          res = string.lower(res)
       else
-	 -- Nothing found, just fallback to the IP address
-	 res = ip
+         -- Nothing found, just fallback to the IP address
+         res = ip
       end
    end
 
@@ -928,7 +931,7 @@ end
 -- NOTE: The function attempt at labelling an host only using information found in host_info.
 -- In case host_info is not enough to label the host, then local caches and DNS resolution kick in
 -- to find a label (at the expense of extra time).
-function hostinfo2label(host_info, show_vlan, shorten_len)
+function hostinfo2label(host_info, show_vlan, shorten_len, skip_resolution)
    local alt_name = nil
    local ip = host_info["ip"] or host_info["host"]
 
@@ -945,7 +948,7 @@ function hostinfo2label(host_info, show_vlan, shorten_len)
 	      res = host_info["name"]
 
         if isEmptyString(res) then
-            return hostinfo2label_resolved(host_info, show_vlan, shorten_len)
+            return hostinfo2label_resolved(host_info, show_vlan, shorten_len, skip_resolution)
         end
       end
    end
@@ -1104,6 +1107,26 @@ end
 
 -- ##############################################
 
+function isHostKey(key)
+  local info = split(key,"@")
+  -- Check format
+  if not info or #info < 1 or #info > 2 then
+    return false
+  end
+  -- Check IP format
+  if isEmptyString(info[1]) or (not isIPv4(info[1]) and not isIPv6(info[1])) then
+    return false
+  end
+  -- Check VLAN format (if any)
+  if not isEmptyString(info[2]) and tonumber(info[2]) == nil then
+    return false
+  end
+  -- Ok
+  return true
+end
+
+-- ##############################################
+
 --
 -- Analyze the host_info table and return the host key.
 -- Example:
@@ -1271,6 +1294,11 @@ end
 -- ##############################################
 
 function tablePreferences(key, value, force_set)
+  if not _SESSION then
+    -- Not in a user session, ignore preferences
+    return
+  end
+
   table_key = getRedisPrefix("ntopng.sort.table")
 
   if((value == nil) or (value == "")) and (force_set ~= true) then
@@ -1854,6 +1882,16 @@ end
 
 -- ##############################################
 
+function setFlowDevAlias(flowdev_ip, alias)
+   if((flowdev_ip ~= alias) and not isEmptyString(alias)) then
+      ntop.setHashCache(getFlowDevAliasKey(), flowdev_ip, alias)
+   else
+      ntop.delHashCache(getFlowDevAliasKey(), flowdev_ip)
+   end
+end
+
+-- ##############################################
+
 function addScoreToAlertDescr(msg, score)
    return (msg .. string.format(" [%s: %s]",
             i18n("score"),
@@ -1865,7 +1903,7 @@ end
 function addHTTPInfoToAlertDescr(msg, alert_json, url_only)
    if ((alert_json)
       and (table.len(alert_json["proto"] or {}) > 0)
-      and (table.len(alert_json["proto"]["http"]) > 0)) then
+      and (table.len(alert_json["proto"]["http"] or {}) > 0)) then
 
       local http_info = format_http_info({ http_info = alert_json["proto"]["http"]["last_method"],
                                             last_return_code = alert_json["proto"]["http"]["last_return_code"],
