@@ -1,7 +1,6 @@
 --
 -- (C) 2019-22 - ntop.org
 --
-
 local ts_utils = require "ts_utils_core"
 local schema
 
@@ -13,7 +12,10 @@ local schema
 -------------------------------------------------------
 
 -- NOTE: always disabled?
-schema = ts_utils.newSchema("mac:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("mac:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("mac")
 schema:addMetric("bytes_sent")
@@ -21,7 +23,9 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("mac:arp_rqst_sent_rcvd_rpls", {step=300})
+schema = ts_utils.newSchema("mac:arp_rqst_sent_rcvd_rpls", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("mac")
 schema:addMetric("request_pkts_sent")
@@ -30,7 +34,9 @@ schema:addMetric("reply_pkts_rcvd")
 -- ##############################################
 
 -- NOTE: always disabled?
-schema = ts_utils.newSchema("mac:ndpi_categories", {step=300})
+schema = ts_utils.newSchema("mac:ndpi_categories", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("mac")
 schema:addTag("category")
@@ -40,7 +46,10 @@ schema:addMetric("bytes")
 -- HOST POOLS SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("host_pool:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("host_pool:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("pool")
 schema:addMetric("bytes_sent")
@@ -48,28 +57,39 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host_pool:hosts", {step = 300, metrics_type = ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("host_pool:hosts", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("pool")
 schema:addMetric("num_hosts")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host_pool:devices", {step = 300, metrics_type = ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("host_pool:devices", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("pool")
 schema:addMetric("num_devices")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host_pool:blocked_flows", {step=300, rrd_fname="blocked_flows"})
+schema = ts_utils.newSchema("host_pool:blocked_flows", {
+    step = 300,
+    rrd_fname = "blocked_flows"
+})
 schema:addTag("ifid")
 schema:addTag("pool")
 schema:addMetric("num_flows")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host_pool:ndpi", {step=300})
+schema = ts_utils.newSchema("host_pool:ndpi", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("pool")
 schema:addTag("protocol")
@@ -80,7 +100,10 @@ schema:addMetric("bytes_rcvd")
 -- ASN SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("asn:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("asn:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("bytes_sent")
@@ -88,7 +111,10 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:score", {step=300, metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("asn:score", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("score")
@@ -97,21 +123,29 @@ schema:addMetric("scoreAsServer")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:traffic_sent", {step=300, rrd_fname="bytes_sent"})
+schema = ts_utils.newSchema("asn:traffic_sent", {
+    step = 300,
+    rrd_fname = "bytes_sent"
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("bytes")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:traffic_rcvd", {step=300, rrd_fname="bytes_rcvd"})
+schema = ts_utils.newSchema("asn:traffic_rcvd", {
+    step = 300,
+    rrd_fname = "bytes_rcvd"
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("bytes")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:ndpi", {step=300})
+schema = ts_utils.newSchema("asn:ndpi", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addTag("protocol")
@@ -120,14 +154,20 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:rtt", {step=300, rrd_fname="num_ms_rtt", metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("asn:rtt", {
+    step = 300,
+    rrd_fname = "num_ms_rtt",
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("millis_rtt")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:tcp_retransmissions", {step=300})
+schema = ts_utils.newSchema("asn:tcp_retransmissions", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("packets_sent")
@@ -135,7 +175,9 @@ schema:addMetric("packets_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:tcp_out_of_order", {step=300})
+schema = ts_utils.newSchema("asn:tcp_out_of_order", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("packets_sent")
@@ -143,7 +185,9 @@ schema:addMetric("packets_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:tcp_lost", {step=300})
+schema = ts_utils.newSchema("asn:tcp_lost", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("packets_sent")
@@ -151,7 +195,9 @@ schema:addMetric("packets_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("asn:tcp_keep_alive", {step=300})
+schema = ts_utils.newSchema("asn:tcp_keep_alive", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("asn")
 schema:addMetric("packets_sent")
@@ -163,7 +209,10 @@ schema:addMetric("packets_rcvd")
 -- COUNTRIES SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("country:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("country:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("country")
 schema:addMetric("bytes_ingress")
@@ -172,7 +221,10 @@ schema:addMetric("bytes_inner")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("country:score", {step=300, metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("country:score", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("country")
 schema:addMetric("score")
@@ -183,7 +235,10 @@ schema:addMetric("scoreAsServer")
 -- OBS POINT SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("obs_point:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("obs_point:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("obs_point")
 schema:addMetric("bytes_sent")
@@ -191,7 +246,10 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("obs_point:score", {step=300, metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("obs_point:score", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("obs_point")
 schema:addMetric("score")
@@ -200,21 +258,29 @@ schema:addMetric("scoreAsServer")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("obs_point:traffic_sent", {step=300, rrd_fname="bytes_sent"})
+schema = ts_utils.newSchema("obs_point:traffic_sent", {
+    step = 300,
+    rrd_fname = "bytes_sent"
+})
 schema:addTag("ifid")
 schema:addTag("obs_point")
 schema:addMetric("bytes")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("obs_point:traffic_rcvd", {step=300, rrd_fname="bytes_rcvd"})
+schema = ts_utils.newSchema("obs_point:traffic_rcvd", {
+    step = 300,
+    rrd_fname = "bytes_rcvd"
+})
 schema:addTag("ifid")
 schema:addTag("obs_point")
 schema:addMetric("bytes")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("obs_point:ndpi", {step=300})
+schema = ts_utils.newSchema("obs_point:ndpi", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("obs_point")
 schema:addTag("protocol")
@@ -225,7 +291,9 @@ schema:addMetric("bytes_rcvd")
 -- OSES SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("os:traffic", {step=300})
+schema = ts_utils.newSchema("os:traffic", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("os")
 schema:addMetric("bytes_ingress")
@@ -235,7 +303,10 @@ schema:addMetric("bytes_egress")
 -- VLAN SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("vlan:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("vlan:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("vlan")
 schema:addMetric("bytes_sent")
@@ -243,7 +314,10 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("vlan:score", {step=300, metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("vlan:score", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("vlan")
 schema:addMetric("score")
@@ -252,7 +326,9 @@ schema:addMetric("scoreAsServer")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("vlan:ndpi", {step=300})
+schema = ts_utils.newSchema("vlan:ndpi", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("vlan")
 schema:addTag("protocol")
@@ -263,7 +339,10 @@ schema:addMetric("bytes_rcvd")
 -- FLOW PROBES SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("sflowdev_port:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("sflowdev_port:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addTag("port")
@@ -272,14 +351,19 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("flowdev_port:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("flowdev_port:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addTag("port")
 schema:addMetric("bytes_sent")
 schema:addMetric("bytes_rcvd")
 
-schema = ts_utils.newSchema("flowdev_port:ndpi", {step = 300})
+schema = ts_utils.newSchema("flowdev_port:ndpi", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addTag("port")
@@ -291,7 +375,10 @@ schema:addMetric("bytes_rcvd")
 -- EVENT EXPORTER SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("evexporter_iface:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("evexporter_iface:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("exporter")
 schema:addTag("ifname")
@@ -302,14 +389,24 @@ schema:addMetric("bytes_rcvd")
 -- SNMP SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("snmp_if:traffic", {step=300, rrd_heartbeat=3000, rrd_fname="bytes", is_system_schema = true})
+schema = ts_utils.newSchema("snmp_if:traffic", {
+    step = 300,
+    rrd_heartbeat = 3000,
+    rrd_fname = "bytes",
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addTag("if_index")
 schema:addMetric("bytes_sent")
 schema:addMetric("bytes_rcvd")
 
-schema = ts_utils.newSchema("snmp_if:packets", {step=300, rrd_heartbeat=3000, rrd_fname="packets", is_system_schema = true})
+schema = ts_utils.newSchema("snmp_if:packets", {
+    step = 300,
+    rrd_heartbeat = 3000,
+    rrd_fname = "packets",
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addTag("if_index")
@@ -318,31 +415,51 @@ schema:addMetric("nucast_sent")
 schema:addMetric("ucast_rcvd")
 schema:addMetric("nucast_rcvd")
 
-schema = ts_utils.newSchema("snmp_if:errors", {step=300, rrd_heartbeat=3000, is_system_schema = true})
+schema = ts_utils.newSchema("snmp_if:errors", {
+    step = 300,
+    rrd_heartbeat = 3000,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addTag("if_index")
 schema:addMetric("packets_disc")
 schema:addMetric("packets_err")
 
-schema = ts_utils.newSchema("snmp_dev:cpu_states", {step = 300, metrics_type = ts_utils.metrics.gauge, is_system_schema = true})
+schema = ts_utils.newSchema("snmp_dev:cpu_states", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addMetric("user_pct")
 schema:addMetric("system_pct")
 schema:addMetric("idle_pct")
 
-schema = ts_utils.newSchema("snmp_dev:avail_memory", {step = 300, metrics_type = ts_utils.metrics.gauge, is_system_schema = true})
+schema = ts_utils.newSchema("snmp_dev:avail_memory", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addMetric("avail_bytes")
 
-schema = ts_utils.newSchema("snmp_dev:swap_memory", {step = 300, metrics_type = ts_utils.metrics.gauge, is_system_schema = true})
+schema = ts_utils.newSchema("snmp_dev:swap_memory", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addMetric("swap_bytes")
 
-schema = ts_utils.newSchema("snmp_dev:total_memory", {step = 300, metrics_type = ts_utils.metrics.gauge, is_system_schema = true})
+schema = ts_utils.newSchema("snmp_dev:total_memory", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("device")
 schema:addMetric("total_bytes")
@@ -351,7 +468,10 @@ schema:addMetric("total_bytes")
 -- HOSTS SCHEMAS
 -------------------------------------------------------
 
-schema = ts_utils.newSchema("host:traffic", {step=300, rrd_fname="bytes"})
+schema = ts_utils.newSchema("host:traffic", {
+    step = 300,
+    rrd_fname = "bytes"
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("bytes_sent")
@@ -359,7 +479,10 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:score", {step=300, metrics_type = ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("host:score", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("score_as_cli")
@@ -367,7 +490,11 @@ schema:addMetric("score_as_srv")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:active_flows", {step=300, rrd_fname="active_flows", metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("host:active_flows", {
+    step = 300,
+    rrd_fname = "active_flows",
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_client")
@@ -375,7 +502,10 @@ schema:addMetric("flows_as_server")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:num_blacklisted_flows", {step=300, rrd_fname="num_blacklisted_flows"})
+schema = ts_utils.newSchema("host:num_blacklisted_flows", {
+    step = 300,
+    rrd_fname = "num_blacklisted_flows"
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_client")
@@ -383,7 +513,10 @@ schema:addMetric("flows_as_server")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:total_flows", {step=300, rrd_fname="total_flows"})
+schema = ts_utils.newSchema("host:total_flows", {
+    step = 300,
+    rrd_fname = "total_flows"
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_client")
@@ -391,7 +524,10 @@ schema:addMetric("flows_as_server")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:alerted_flows", {step = 300, rrd_fname = "alerted_flows"})
+schema = ts_utils.newSchema("host:alerted_flows", {
+    step = 300,
+    rrd_fname = "alerted_flows"
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_client")
@@ -399,7 +535,10 @@ schema:addMetric("flows_as_server")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:unreachable_flows", {step = 300, rrd_fname = "unreachable_flows"})
+schema = ts_utils.newSchema("host:unreachable_flows", {
+    step = 300,
+    rrd_fname = "unreachable_flows"
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_client")
@@ -407,7 +546,9 @@ schema:addMetric("flows_as_server")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:host_unreachable_flows", {step = 300})
+schema = ts_utils.newSchema("host:host_unreachable_flows", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_server")
@@ -415,105 +556,134 @@ schema:addMetric("flows_as_client")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:host_tcp_unidirectional_flows", {step = 300})
+schema = ts_utils.newSchema("host:host_tcp_unidirectional_flows", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("flows_as_server")
 schema:addMetric("flows_as_client")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:ndpi_flows", {step = 300})
+schema = ts_utils.newSchema("host:ndpi_flows", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("protocol")
 schema:addMetric("num_flows")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:echo_packets", {step = 300})
+schema = ts_utils.newSchema("host:echo_packets", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("packets_sent")
 schema:addMetric("packets_rcvd")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:echo_reply_packets", {step = 300})
+schema = ts_utils.newSchema("host:echo_reply_packets", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("packets_sent")
 schema:addMetric("packets_rcvd")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:dns_qry_sent_rsp_rcvd", {step = 300})
+schema = ts_utils.newSchema("host:dns_qry_sent_rsp_rcvd", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("queries_pkts")
 schema:addMetric("replies_ok_pkts")
 schema:addMetric("replies_error_pkts")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:dns_qry_rcvd_rsp_sent", {step = 300})
+schema = ts_utils.newSchema("host:dns_qry_rcvd_rsp_sent", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("queries_pkts")
 schema:addMetric("replies_ok_pkts")
 schema:addMetric("replies_error_pkts")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:tcp_rx_stats", {step = 300})
+schema = ts_utils.newSchema("host:tcp_rx_stats", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("retran_pkts")
 schema:addMetric("out_of_order_pkts")
 schema:addMetric("lost_packets")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:tcp_tx_stats", {step = 300})
+schema = ts_utils.newSchema("host:tcp_tx_stats", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("retran_pkts")
 schema:addMetric("out_of_order_pkts")
 schema:addMetric("lost_packets")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:tcp_packets", {step = 300})
+schema = ts_utils.newSchema("host:tcp_packets", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("packets_sent")
 schema:addMetric("packets_rcvd")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:udp_pkts", {step = 300})
+schema = ts_utils.newSchema("host:udp_pkts", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("packets_sent")
 schema:addMetric("packets_rcvd")
 
---##############################################
+-- ##############################################
 
-schema = ts_utils.newSchema("host:total_alerts", {step = 300, rrd_fname = "total_alerts"})
-schema:addTag("ifid")
-schema:addTag("host")
-schema:addMetric("alerts")
-
---##############################################
-
-schema = ts_utils.newSchema("host:engaged_alerts", {step = 300, metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("host:total_alerts", {
+    step = 300,
+    rrd_fname = "total_alerts"
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("alerts")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:contacts", {step=300, metrics_type=ts_utils.metrics.gauge})
+schema = ts_utils.newSchema("host:engaged_alerts", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
+schema:addTag("ifid")
+schema:addTag("host")
+schema:addMetric("alerts")
+
+-- ##############################################
+
+schema = ts_utils.newSchema("host:contacts", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("num_as_client")
@@ -521,7 +691,9 @@ schema:addMetric("num_as_server")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:l4protos", {step=300})
+schema = ts_utils.newSchema("host:l4protos", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("l4proto")
@@ -530,7 +702,9 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:dscp", {step=300})
+schema = ts_utils.newSchema("host:dscp", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("dscp_class")
@@ -539,7 +713,9 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:udp_sent_unicast", {step=300})
+schema = ts_utils.newSchema("host:udp_sent_unicast", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("bytes_sent_unicast")
@@ -547,7 +723,9 @@ schema:addMetric("bytes_sent_non_uni")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:ndpi", {step=300})
+schema = ts_utils.newSchema("host:ndpi", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("protocol")
@@ -556,7 +734,9 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("host:ndpi_categories", {step=300})
+schema = ts_utils.newSchema("host:ndpi_categories", {
+    step = 300
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("category")
@@ -566,13 +746,24 @@ schema:addMetric("bytes_rcvd")
 -- ##############################################
 
 -- NOTE: these are "virtual" schema, they do not correspond to actual timeseries
-schema = ts_utils.newSchema("local_senders", {step=300, is_system_schema = true})
+schema = ts_utils.newSchema("local_senders", {
+    step = 300,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 
-schema = ts_utils.newSchema("local_receivers", {step=300, is_system_schema = true})
+schema = ts_utils.newSchema("local_receivers", {
+    step = 300,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 
-schema = ts_utils.newSchema("am_host:val_5mins", { step = 300, metrics_type = ts_utils.metrics.gauge, aggregation_function = ts_utils.aggregation.max, is_system_schema = true })
+schema = ts_utils.newSchema("am_host:val_5mins", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    aggregation_function = ts_utils.aggregation.max,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("metric")
@@ -586,7 +777,12 @@ schema:addMetric("value")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("am_host:http_stats_5mins", { step = 300, metrics_type = ts_utils.metrics.gauge, aggregation_function = ts_utils.aggregation.max, is_system_schema = true })
+schema = ts_utils.newSchema("am_host:http_stats_5mins", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    aggregation_function = ts_utils.aggregation.max,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("metric")
@@ -595,7 +791,12 @@ schema:addMetric("other_ms")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("am_host:https_stats_5mins", { step = 300, metrics_type = ts_utils.metrics.gauge, aggregation_function = ts_utils.aggregation.max, is_system_schema = true })
+schema = ts_utils.newSchema("am_host:https_stats_5mins", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    aggregation_function = ts_utils.aggregation.max,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addTag("metric")
@@ -605,14 +806,22 @@ schema:addMetric("other_ms")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("am_host:upload_5mins", { step = 300, metrics_type = ts_utils.metrics.gauge, is_system_schema = true })
+schema = ts_utils.newSchema("am_host:upload_5mins", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("speed")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("am_host:latency_5mins", { step = 300, metrics_type = ts_utils.metrics.gauge, is_system_schema = true })
+schema = ts_utils.newSchema("am_host:latency_5mins", {
+    step = 300,
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true
+})
 schema:addTag("ifid")
 schema:addTag("host")
 schema:addMetric("latency")
@@ -620,50 +829,80 @@ schema:addMetric("latency")
 -------------------------------------------------------
 -- INFLUXDB SCHEMAS
 -------------------------------------------------------
- 
+
 -- ##############################################
 
-schema = ts_utils.newSchema("influxdb:storage_size", { metrics_type = ts_utils.metrics.gauge, is_system_schema = true, step = 300 })
+schema = ts_utils.newSchema("influxdb:storage_size", {
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true,
+    step = 300
+})
 schema:addTag("ifid")
 schema:addMetric("disk_bytes")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("influxdb:exported_points", { metrics_type = ts_utils.metrics.counter, is_system_schema = true, step = 300 })
+schema = ts_utils.newSchema("influxdb:exported_points", {
+    metrics_type = ts_utils.metrics.counter,
+    is_system_schema = true,
+    step = 300
+})
 schema:addTag("ifid")
 schema:addMetric("points")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("influxdb:dropped_points", { metrics_type = ts_utils.metrics.counter, is_system_schema = true, step = 300 })
+schema = ts_utils.newSchema("influxdb:dropped_points", {
+    metrics_type = ts_utils.metrics.counter,
+    is_system_schema = true,
+    step = 300
+})
 schema:addTag("ifid")
 schema:addMetric("points")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("influxdb:exports", { metrics_type = ts_utils.metrics.counter, is_system_schema = true, step = 300 })
+schema = ts_utils.newSchema("influxdb:exports", {
+    metrics_type = ts_utils.metrics.counter,
+    is_system_schema = true,
+    step = 300
+})
 schema:addTag("ifid")
 schema:addMetric("num_exports")
 
 -- ##############################################
 
-schema = ts_utils.newSchema("influxdb:rtt", { metrics_type = ts_utils.metrics.gauge, is_system_schema = true, step = 300 })
+schema = ts_utils.newSchema("influxdb:rtt", {
+    metrics_type = ts_utils.metrics.gauge,
+    is_system_schema = true,
+    step = 300
+})
 schema:addTag("ifid")
 schema:addMetric("millis_rtt")
 
 -- ##############################################
 
 -- The following metrics are built-in into influxdb
-schema = ts_utils.newSchema("influxdb:memory_size", { influx_internal_query = ts_utils.get_memory_size_query, is_system_schema = true, metrics_type = ts_utils.metrics.gauge, step = 10 })
+schema = ts_utils.newSchema("influxdb:memory_size", {
+    influx_internal_query = ts_utils.get_memory_size_query,
+    is_system_schema = true,
+    metrics_type = ts_utils.metrics.gauge,
+    step = 10
+})
 schema:addTag("ifid")
 schema:addMetric("mem_bytes")
- 
+
 -- ##############################################
 
-schema = ts_utils.newSchema("influxdb:write_successes", { influx_internal_query = ts_utils.get_write_success_query, is_system_schema = true, metrics_type = ts_utils.metrics.counter, step = 10 })
+schema = ts_utils.newSchema("influxdb:write_successes", {
+    influx_internal_query = ts_utils.get_write_success_query,
+    is_system_schema = true,
+    metrics_type = ts_utils.metrics.counter,
+    step = 10
+})
 schema:addTag("ifid")
 schema:addMetric("points")
- 
+
 -------------------------------------------------------
 -- PRO VERSION SCHEMAS
 -------------------------------------------------------
@@ -674,40 +913,23 @@ if ntop.isPro() then
     -------------------------------------------------------
     -- ASN SCHEMAS
     -------------------------------------------------------
-    
-    schema = ts_utils.newSchema("asn:traffic_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
+
+    -- ##############################################
+
+    schema = ts_utils.newSchema("asn:score_anomalies", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("asn")
     schema:addMetric("anomaly")
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("asn:traffic_tx_behavior_v2", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addTag("asn")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("asn:traffic_rx_behavior_v2", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addTag("asn")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("asn:score_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addTag("asn")
-    schema:addMetric("anomaly")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("asn:score_behavior", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("asn:score_behavior", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("asn")
     schema:addMetric("value")
@@ -717,77 +939,27 @@ if ntop.isPro() then
     -------------------------------------------------------
     -- INTERFACE SCHEMAS
     -------------------------------------------------------
-    schema = ts_utils.newSchema("iface:traffic_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addMetric("anomaly")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("iface:traffic_tx_behavior_v2", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("iface:traffic_rx_behavior_v2", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("iface:score_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addMetric("anomaly")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("iface:score_behavior", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
 
     -------------------------------------------------------
     -- SUBNET SCHEMAS
     -------------------------------------------------------
 
-    schema = ts_utils.newSchema("subnet:traffic_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
+    -- ##############################################
+
+    schema = ts_utils.newSchema("subnet:score_anomalies", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("subnet")
     schema:addMetric("anomaly")
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("subnet:traffic_tx_behavior_v2", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addTag("subnet")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("subnet:traffic_rx_behavior_v2", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addTag("subnet")
-    schema:addMetric("value")
-    schema:addMetric("lower_bound")
-    schema:addMetric("upper_bound")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("subnet:score_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
-    schema:addTag("ifid")
-    schema:addTag("subnet")
-    schema:addMetric("anomaly")
-
-    -- ##############################################
-
-    schema = ts_utils.newSchema("subnet:score_behavior", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("subnet:score_behavior", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("subnet")
     schema:addMetric("value")
@@ -798,7 +970,10 @@ if ntop.isPro() then
     -- HOST SCHEMAS
     -------------------------------------------------------
 
-    schema = ts_utils.newSchema("host:contacts_behaviour", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:contacts_behaviour", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("value")
@@ -807,7 +982,10 @@ if ntop.isPro() then
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:cli_active_flows_behaviour", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:cli_active_flows_behaviour", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("value")
@@ -816,7 +994,10 @@ if ntop.isPro() then
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:srv_active_flows_behaviour", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:srv_active_flows_behaviour", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("value")
@@ -825,7 +1006,10 @@ if ntop.isPro() then
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:cli_score_behaviour", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:cli_score_behaviour", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("value")
@@ -834,7 +1018,10 @@ if ntop.isPro() then
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:srv_score_behaviour", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:srv_score_behaviour", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("value")
@@ -842,28 +1029,40 @@ if ntop.isPro() then
     schema:addMetric("upper_bound")
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:cli_active_flows_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:cli_active_flows_anomalies", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("anomaly")
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:srv_active_flows_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:srv_active_flows_anomalies", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("anomaly")
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:cli_score_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:cli_score_anomalies", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("anomaly")
 
     -- ##############################################
 
-    schema = ts_utils.newSchema("host:srv_score_anomalies", {step=300, metrics_type=ts_utils.metrics.gauge})
+    schema = ts_utils.newSchema("host:srv_score_anomalies", {
+        step = 300,
+        metrics_type = ts_utils.metrics.gauge
+    })
     schema:addTag("ifid")
     schema:addTag("host")
     schema:addMetric("anomaly")
