@@ -21,7 +21,7 @@ local prefs = ntop.getPrefs()
 local ToastLevel = toast_ui.ToastLevels
 
 -- Constants
-local ALARM_THRESHOLD_LOW = 60
+local ALARM_THRESHOLD_LOW = 80
 local ALARM_THRESHOLD_HIGH = 90
 local IS_ADMIN = isAdministrator()
 local IS_SYSTEM_INTERFACE = page_utils.is_system_view()
@@ -349,10 +349,12 @@ function predicates.mirrored_traffic(toast, container)
     for _, traffic in pairs(ifstats.upload_stats) do
       upload_traffic = upload_traffic + traffic
     end
- 
+    
+    local is_mirrored_traffic_pref = ntop.getPref(string.format("ntopng.prefs.ifid_%d.is_traffic_mirrored", interface.getId())) == "0"
+    
     if is_not_oem_and_administrator and not isEmptyString(message) and 
       (num_tot_traffic_points > 10) and 
-      (upload_traffic == 0 and download_traffic > 0) then
+      (upload_traffic == 0 and download_traffic > 0 and is_mirrored_traffic_pref) then
         table.insert(container, create_mirrored_traffic_toast(toast, message))
     end
 end
