@@ -20,7 +20,7 @@ local ifId = getInterfaceId(ifname)
 sendHTTPContentTypeHeader('text/html')
 
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.pods)
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.pods)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
  
