@@ -585,10 +585,11 @@ if not is_system_interface then
 
    if #results == 0 and not isEmptyString(query) then
       -- No results - add shortcut to search in historical data
+      --tprint(query)
       if hasClickHouseSupport() then
          local label = ""
          local what = ""
-         if isIPv6(query) or isIPv4(query) then
+         if isHostKey(query) then
             what = "ip"
             label = i18n("db_search.find_in_historical", {what=what, query=query})
             query = query .. tag_utils.SEPARATOR .. "eq"
@@ -596,11 +597,27 @@ if not is_system_interface then
             what = "mac"
             label = i18n("db_search.find_in_historical", {what=what, query=query})
             query = query .. tag_utils.SEPARATOR .. "eq"
+         elseif isCommunityId(query) then
+         --tprint("HERE")
+            what = "community_id"
+            label = i18n("db_search.find_in_historical", {what=what, query=query})
+            query = query .. tag_utils.SEPARATOR .. "eq"
+         elseif isJA3(query) then
+         --tprint("HERE")
+            what = "ja3_client"
+            label = i18n("db_search.find_in_historical", {what=what, query=query})
+            query = query .. tag_utils.SEPARATOR .. "eq"
+            results[#results + 1] = build_result(label, query, what, nil, nil, "historical")
+            what = "ja3_server"
+            label = i18n("db_search.find_in_historical", {what=what, query=query})
+            query = query .. tag_utils.SEPARATOR .. "eq"
          else
             what = "hostname"
             label = i18n("db_search.find_in_historical", {what=what, query=query})
             query = query .. tag_utils.SEPARATOR .. "in"
          end
+
+         --tprint(query)
          results[#results + 1] = build_result(label, query, what, nil, nil, "historical")
       end
    end
