@@ -24,7 +24,7 @@ ifId = getInterfaceId(ifname)
 sendHTTPContentTypeHeader('text/html')
 
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.vlans)
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.vlans)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
