@@ -16,7 +16,7 @@ if (group_col == nil) then
    group_col = "asn"
 end
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.vlans)
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.vlans)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
