@@ -24,11 +24,11 @@
 
 /* **************************************************** */
 
-ChecksLoader::ChecksLoader(){
+ChecksLoader::ChecksLoader() {
   /* Set the ntopng version matching the loaded checks */
   if (ntop->getPrefs()->is_enterprise_l_edition())
     checks_edition = ntopng_edition_enterprise_l;
-  else if (ntop->getPrefs()->is_enterprise_m_edition())	  
+  else if (ntop->getPrefs()->is_enterprise_m_edition())
     checks_edition = ntopng_edition_enterprise_m;
   else if (ntop->getPrefs()->is_pro_edition())
     checks_edition = ntopng_edition_pro;
@@ -38,5 +38,4 @@ ChecksLoader::ChecksLoader(){
 
 /* **************************************************** */
 
-ChecksLoader::~ChecksLoader() {
-}
+ChecksLoader::~ChecksLoader() {}
