@@ -21,6 +21,8 @@
 
 #include "ntop_includes.h"
 
+
+#ifdef HAVE_ZMQ
 #ifndef HAVE_NEDGE
 
 /* **************************************************** */
@@ -28,21 +30,22 @@
 ExportInterface::ExportInterface(const char *_endpoint, const char *_topic) {
   topic = strdup(_topic), endpoint = strdup(_endpoint);
 
-  if((context = zmq_ctx_new()) == NULL) {
+  if ((context = zmq_ctx_new()) == NULL) {
     const char *msg = "Unable to initialize ZMQ context";
     ntop->getTrace()->traceEvent(TRACE_ERROR, msg);
     throw(msg);
   }
 
-  if((publisher = zmq_socket(context, ZMQ_PUB)) == NULL) {
+  if ((publisher = zmq_socket(context, ZMQ_PUB)) == NULL) {
     const char *msg = "Unable to create ZMQ socket";
     ntop->getTrace()->traceEvent(TRACE_ERROR, msg);
     throw(msg);
   }
 
-#if ZMQ_VERSION >= ZMQ_MAKE_VERSION(4,1,0)
+#if ZMQ_VERSION >= ZMQ_MAKE_VERSION(4, 1, 0)
   if (ntop->getPrefs()->get_export_zmq_encryption_key()) {
-    const char *server_public_key = ntop->getPrefs()->get_export_zmq_encryption_key();
+    const char *server_public_key =
+        ntop->getPrefs()->get_export_zmq_encryption_key();
     char client_public_key[41];
     char client_secret_key[41];
     int rc;
@@ -56,54 +59,60 @@ ExportInterface::ExportInterface(const char *_endpoint, const char *_topic) {
     }
 
     if (strlen(server_public_key) != 40) {
-      ntop->getTrace()->traceEvent(TRACE_ERROR, "Bad ZMQ server public key size (%lu != 40) '%s'", 
-				   strlen(server_public_key), server_public_key);
+      ntop->getTrace()->traceEvent(
+          TRACE_ERROR, "Bad ZMQ server public key size (%lu != 40) '%s'",
+          strlen(server_public_key), server_public_key);
       throw("Bad ZMQ server public key size");
     }
 
-    rc = zmq_setsockopt(publisher, ZMQ_CURVE_SERVERKEY,
-			server_public_key, strlen(server_public_key)+1);
+    rc = zmq_setsockopt(publisher, ZMQ_CURVE_SERVERKEY, server_public_key,
+                        strlen(server_public_key) + 1);
 
     if (rc != 0) {
-      ntop->getTrace()->traceEvent(TRACE_ERROR, "Error setting ZMQ_CURVE_SERVERKEY = %s (%d)", 
-				   server_public_key, errno);
+      ntop->getTrace()->traceEvent(
+          TRACE_ERROR, "Error setting ZMQ_CURVE_SERVERKEY = %s (%d)",
+          server_public_key, errno);
       throw("Error setting ZMQ_CURVE_SERVERKEY");
     }
-    
-    rc = zmq_setsockopt(publisher, ZMQ_CURVE_PUBLICKEY,
-			client_public_key, strlen(client_public_key)+1);
-    
+
+    rc = zmq_setsockopt(publisher, ZMQ_CURVE_PUBLICKEY, client_public_key,
+                        strlen(client_public_key) + 1);
+
     if (rc != 0) {
-      ntop->getTrace()->traceEvent(TRACE_ERROR, "Error setting ZMQ_CURVE_PUBLICKEY = %s",
-				   client_public_key);
+      ntop->getTrace()->traceEvent(TRACE_ERROR,
+                                   "Error setting ZMQ_CURVE_PUBLICKEY = %s",
+                                   client_public_key);
       throw("Error setting ZMQ_CURVE_PUBLICKEY");
     }
 
-    rc = zmq_setsockopt(publisher, ZMQ_CURVE_SECRETKEY, client_secret_key, 
-			strlen(client_secret_key)+1);
+    rc = zmq_setsockopt(publisher, ZMQ_CURVE_SECRETKEY, client_secret_key,
+                        strlen(client_secret_key) + 1);
 
     if (rc != 0) {
-      ntop->getTrace()->traceEvent(TRACE_ERROR, "Error setting ZMQ_CURVE_SECRETKEY = %s",
-				   client_secret_key);
+      ntop->getTrace()->traceEvent(TRACE_ERROR,
+                                   "Error setting ZMQ_CURVE_SECRETKEY = %s",
+                                   client_secret_key);
       throw("Error setting ZMQ_CURVE_SECRETKEY");
     }
   }
 #endif
 
-  if(zmq_bind(publisher, endpoint) != 0) {
-    ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to bind ZMQ endpoint %s: %s",
-      endpoint, strerror(errno));
+  if (zmq_bind(publisher, endpoint) != 0) {
+    ntop->getTrace()->traceEvent(TRACE_ERROR,
+                                 "Unable to bind ZMQ endpoint %s: %s", endpoint,
+                                 strerror(errno));
     throw("Unable to bind ZMQ endpoint");
   }
 
-  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Successfully created ZMQ endpoint %s", endpoint);
+  ntop->getTrace()->traceEvent(
+      TRACE_NORMAL, "Successfully created ZMQ endpoint %s", endpoint);
 }
 
 /* **************************************************** */
 
 ExportInterface::~ExportInterface() {
-  if(topic)    free(topic);
-  if(endpoint) free(endpoint);
+  if (topic) free(topic);
+  if (endpoint) free(endpoint);
 
   zmq_close(publisher);
   zmq_ctx_destroy(context);
@@ -112,7 +121,7 @@ ExportInterface::~ExportInterface() {
 /* **************************************************** */
 
 void ExportInterface::export_data(char *json) {
-  if(publisher) {
+  if (publisher) {
     struct zmq_msg_hdr_v1 msg_hdr;
 
     snprintf(msg_hdr.url, sizeof(msg_hdr.url), "%s", topic);
@@ -127,3 +136,4 @@ void ExportInterface::export_data(char *json) {
 /* **************************************************** */
 
 #endif
+#endif
