@@ -23,55 +23,52 @@
 
 /* *************************************** */
 
-ICMPstats::ICMPstats() {
-  num_destination_unreachable.reset();
-}
+ICMPstats::ICMPstats() { num_destination_unreachable.reset(); }
 
 /* *************************************** */
 
 ICMPstats::~ICMPstats() {
   std::map<u_int16_t, ICMPstats_t>::const_iterator it;
 
-  for(it = stats.begin(); it != stats.end(); ++it) {
-    if(it->second.last_host_sent_peer) free(it->second.last_host_sent_peer);
-    if(it->second.last_host_rcvd_peer) free(it->second.last_host_rcvd_peer);
+  for (it = stats.begin(); it != stats.end(); ++it) {
+    if (it->second.last_host_sent_peer) free(it->second.last_host_sent_peer);
+    if (it->second.last_host_rcvd_peer) free(it->second.last_host_rcvd_peer);
   }
   stats.clear();
 }
 
 /* *************************************** */
 
-void ICMPstats::incStats(u_int32_t num_pkts, u_int8_t icmp_type, u_int8_t icmp_code, bool sent, Host *peer) {
+void ICMPstats::incStats(u_int32_t num_pkts, u_int8_t icmp_type,
+                         u_int8_t icmp_code, bool sent, Host *peer) {
   std::map<u_int16_t, ICMPstats_t>::const_iterator it;
   ICMPstats_t s;
   u_int16_t key = get_typecode(icmp_type, icmp_code);
   char buf[64];
 
-  if(!num_pkts)
-    return;
+  if (!num_pkts) return;
 
   m.lock(__FILE__, __LINE__);
 
-  if((it = stats.find(key)) != stats.end())
+  if ((it = stats.find(key)) != stats.end())
     s = it->second;
   else
     memset(&s, 0, sizeof(s));
 
-  if(icmp_type == ICMP_DEST_UNREACH)
-    num_destination_unreachable.inc(num_pkts);
+  if (icmp_type == ICMP_DEST_UNREACH) num_destination_unreachable.inc(num_pkts);
 
-  if(sent) {
+  if (sent) {
     s.pkt_sent += num_pkts;
 
-    if(peer) {
-      if(s.last_host_sent_peer) free(s.last_host_sent_peer);
+    if (peer) {
+      if (s.last_host_sent_peer) free(s.last_host_sent_peer);
       s.last_host_sent_peer = strdup(peer->get_string_key(buf, sizeof(buf)));
     }
   } else {
     s.pkt_rcvd += num_pkts;
 
-    if(peer) {
-      if(s.last_host_rcvd_peer) free(s.last_host_rcvd_peer);
+    if (peer) {
+      if (s.last_host_rcvd_peer) free(s.last_host_rcvd_peer);
       s.last_host_rcvd_peer = strdup(peer->get_string_key(buf, sizeof(buf)));
     }
   }
@@ -83,14 +80,17 @@ void ICMPstats::incStats(u_int32_t num_pkts, u_int8_t icmp_type, u_int8_t icmp_c
 
 /* *************************************** */
 
-void ICMPstats::addToTable(const char *label, lua_State *vm, const ICMPstats_t *curr, bool verbose) {
+void ICMPstats::addToTable(const char *label, lua_State *vm,
+                           const ICMPstats_t *curr, bool verbose) {
   lua_newtable(vm);
   lua_push_uint64_table_entry(vm, "sent", curr->pkt_sent);
-  if(verbose)
-    lua_push_str_table_entry(vm, "last_host_sent_peer", curr->last_host_sent_peer);
+  if (verbose)
+    lua_push_str_table_entry(vm, "last_host_sent_peer",
+                             curr->last_host_sent_peer);
   lua_push_uint64_table_entry(vm, "rcvd", curr->pkt_rcvd);
-  if(verbose)
-    lua_push_str_table_entry(vm, "last_host_rcvd_peer", curr->last_host_rcvd_peer);
+  if (verbose)
+    lua_push_str_table_entry(vm, "last_host_rcvd_peer",
+                             curr->last_host_rcvd_peer);
   lua_pushstring(vm, label);
   lua_insert(vm, -2);
   lua_settable(vm, -3);
@@ -98,7 +98,7 @@ void ICMPstats::addToTable(const char *label, lua_State *vm, const ICMPstats_t *
 
 /* ******************************************* */
 
-void ICMPstats::updateStats(const struct timeval * const tv) {
+void ICMPstats::updateStats(const struct timeval *const tv) {
   time_t when = tv->tv_sec;
 
   num_destination_unreachable.computeAnomalyIndex(when);
@@ -108,7 +108,7 @@ void ICMPstats::updateStats(const struct timeval * const tv) {
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "num_destination_unreachable: %s",
 			       num_destination_unreachable.print(buf, sizeof(buf)));
 #endif
- }
+}
 
 /* *************************************** */
 
@@ -119,7 +119,7 @@ void ICMPstats::lua(bool isV4, lua_State *vm, bool verbose) {
 
   lua_newtable(vm);
 
-  for(it = stats.begin(); it != stats.end(); ++it) {
+  for (it = stats.begin(); it != stats.end(); ++it) {
     u_int8_t icmp_type, icmp_code;
     char label[32];
 
@@ -144,7 +144,7 @@ bool ICMPstats::hasAnomalies(time_t when) {
 /* *************************************** */
 
 void ICMPstats::luaAnomalies(lua_State *vm, time_t when) {
-  if(num_destination_unreachable.is_misbehaving(when))
+  if (num_destination_unreachable.is_misbehaving(when))
     num_destination_unreachable.lua(vm, "icmp.num_destination_unreachable");
 }
 
@@ -153,23 +153,23 @@ void ICMPstats::luaAnomalies(lua_State *vm, time_t when) {
 void ICMPstats::sum(ICMPstats *e) {
   std::map<u_int16_t, ICMPstats_t>::const_iterator orig_it;
 
-  for(orig_it = e->stats.begin(); orig_it != e->stats.end(); ++orig_it) {
+  for (orig_it = e->stats.begin(); orig_it != e->stats.end(); ++orig_it) {
     std::map<u_int16_t, ICMPstats_t>::const_iterator it;
     ICMPstats_t s;
     u_int16_t key = orig_it->first;
     const ICMPstats_t *curr = &orig_it->second;
 
-    if((it = stats.find(key)) != stats.end())
+    if ((it = stats.find(key)) != stats.end())
       s = it->second;
     else
       memset(&s, 0, sizeof(s));
 
     s.pkt_sent = curr->pkt_sent, s.pkt_rcvd = curr->pkt_rcvd;
 
-    if(curr->last_host_sent_peer && (! s.last_host_sent_peer))
+    if (curr->last_host_sent_peer && (!s.last_host_sent_peer))
       s.last_host_sent_peer = strdup(curr->last_host_sent_peer);
 
-    if(curr->last_host_rcvd_peer && (! s.last_host_rcvd_peer))
+    if (curr->last_host_rcvd_peer && (!s.last_host_rcvd_peer))
       s.last_host_rcvd_peer = strdup(curr->last_host_rcvd_peer);
 
     stats[key] = s;
@@ -185,15 +185,15 @@ void ICMPstats::getTsStats(ts_icmp_stats *s) {
   std::map<u_int16_t, ICMPstats_t>::const_iterator it;
 
   s->echo_packets_sent = s->echo_packets_rcvd = 0;
-  
+
   m.lock(__FILE__, __LINE__);
 
-  if((it = stats.find(echo_key)) != stats.end()) {
+  if ((it = stats.find(echo_key)) != stats.end()) {
     s->echo_packets_sent = it->second.pkt_sent;
     s->echo_packets_rcvd = it->second.pkt_rcvd;
   }
 
-  if((it = stats.find(echo_reply_key)) != stats.end()) {
+  if ((it = stats.find(echo_reply_key)) != stats.end()) {
     s->echo_reply_packets_sent = it->second.pkt_sent;
     s->echo_reply_packets_rcvd = it->second.pkt_rcvd;
   }
