@@ -23,42 +23,41 @@
 
 /* ************************************ */
 
-MacHash::MacHash(NetworkInterface *_iface, u_int _num_hashes, u_int _max_hash_size) :
-  GenericHash(_iface, _num_hashes, _max_hash_size, "MacHash") {
+MacHash::MacHash(NetworkInterface *_iface, u_int _num_hashes,
+                 u_int _max_hash_size)
+    : GenericHash(_iface, _num_hashes, _max_hash_size, "MacHash") {
   ;
 }
 
 /* ************************************ */
 
-Mac* MacHash::get(const u_int8_t mac[6], bool is_inline_call) {
-  if(mac == NULL)
-    return(NULL);
+Mac *MacHash::get(const u_int8_t mac[6], bool is_inline_call) {
+  if (mac == NULL)
+    return (NULL);
   else {
-    u_int32_t hash = Utils::macHash((u_int8_t*)mac);
+    u_int32_t hash = Utils::macHash((u_int8_t *)mac);
 
     hash %= num_hashes;
 
-    if(table[hash] == NULL) {
-      return(NULL);
+    if (table[hash] == NULL) {
+      return (NULL);
     } else {
       Mac *head;
 
-      if(!is_inline_call)
-	locks[hash]->rdlock(__FILE__, __LINE__);
+      if (!is_inline_call) locks[hash]->rdlock(__FILE__, __LINE__);
 
-      head = (Mac*)table[hash];
+      head = (Mac *)table[hash];
 
-      while(head != NULL) {
-	if((!head->idle()) && head->equal(mac))
-	  break;
-	else
-	  head = (Mac*)head->next();
+      while (head != NULL) {
+        if ((!head->idle()) && head->equal(mac))
+          break;
+        else
+          head = (Mac *)head->next();
       }
 
-      if(!is_inline_call)
-	locks[hash]->unlock(__FILE__, __LINE__);
+      if (!is_inline_call) locks[hash]->unlock(__FILE__, __LINE__);
 
-      return(head);
+      return (head);
     }
   }
 }
