@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-18 - ntop.org
+ * (C) 2015-23 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,34 +23,34 @@
 
 /* *********************************************************** */
 
-VirtualHostHash::VirtualHostHash(NetworkInterface *_iface, u_int _num_hashes, u_int _max_hash_size)
-  : GenericHash(_iface, _num_hashes, _max_hash_size, "VirtualHostHash") {
+VirtualHostHash::VirtualHostHash(NetworkInterface *_iface, u_int _num_hashes,
+                                 u_int _max_hash_size)
+    : GenericHash(_iface, _num_hashes, _max_hash_size, "VirtualHostHash") {
   ;
 }
 
 /* *********************************************************** */
 
-VirtualHost* VirtualHostHash::get(char *key) {
-  u_int32_t hash = Utils::hashString(key) % num_hashes;
+VirtualHost *VirtualHostHash::get(char *vhost_name) {
+  u_int32_t hash = Utils::hashString(vhost_name) % num_hashes;
 
-  if(table[hash] == NULL) {
-    return(NULL);
+  if (table[hash] == NULL) {
+    return (NULL);
   } else {
     VirtualHost *head;
 
-    locks[hash]->lock(__FILE__, __LINE__);
-    head = (VirtualHost*)table[hash];
-    
-    while(head != NULL) {      
-      if((!head->idle())
-	 && head->get_name()
-	 && (strcmp(key, head->get_name()) == 0))
-	break;
+    locks[hash]->wrlock(__FILE__, __LINE__);
+    head = (VirtualHost *)table[hash];
+
+    while (head != NULL) {
+      if ((!head->idle()) && head->get_name() &&
+          (strcmp(vhost_name, head->get_name()) == 0))
+        break;
       else
-	head = (VirtualHost*)head->next();
+        head = (VirtualHost *)head->next();
     }
     locks[hash]->unlock(__FILE__, __LINE__);
 
-    return(head);
+    return (head);
   }
 }
