@@ -21,10 +21,9 @@
 
 #include "flow_alerts_includes.h"
 
-ndpi_serializer* FlowRiskSSHObsoleteServerAlert::getAlertJSON(ndpi_serializer* serializer) {
-  if(serializer == NULL)
-    return NULL;
+ndpi_serializer* FlowRiskSSHObsoleteServerAlert::getAlertJSON(
+    ndpi_serializer* serializer) {
+  if (serializer == NULL) return NULL;
 
   return serializer;
 }
-
