@@ -23,15 +23,14 @@
 
 /* ***************************************************** */
 
-ndpi_serializer *FlowRiskSuspiciousDGADomainAlert::getAlertJSON(ndpi_serializer* serializer) {
+ndpi_serializer *FlowRiskSuspiciousDGADomainAlert::getAlertJSON(
+    ndpi_serializer *serializer) {
   Flow *f = getFlow();
   char *info = f->getDGADomain();
-  
-  if((serializer == NULL) || (info == NULL))
-    return NULL;
+
+  if ((serializer == NULL) || (info == NULL)) return NULL;
 
   ndpi_serialize_string_string(serializer, "dga_domain", info);
-  
+
   return serializer;
 }
-
