@@ -21,8 +21,8 @@
 
 #include "flow_checks_includes.h"
 
-ndpi_serializer* IECUnexpectedTypeIdAlert::getAlertJSON(ndpi_serializer* serializer) {
-
+ndpi_serializer* IECUnexpectedTypeIdAlert::getAlertJSON(
+    ndpi_serializer* serializer) {
   if (serializer) {
     ndpi_serialize_string_uint32(serializer, "type_id", type_id);
     ndpi_serialize_string_uint32(serializer, "asdu", asdu);
@@ -32,4 +32,3 @@ ndpi_serializer* IECUnexpectedTypeIdAlert::getAlertJSON(ndpi_serializer* seriali
 
   return serializer;
 }
-
