@@ -22,12 +22,9 @@
 #include "flow_checks_includes.h"
 
 ndpi_serializer* LongLivedFlowAlert::getAlertJSON(ndpi_serializer* serializer) {
-
-  if(serializer == NULL)
-    return NULL;
+  if (serializer == NULL) return NULL;
 
   ndpi_serialize_string_uint64(serializer, "longlived.threshold", longlived_th);
 
   return serializer;
 }
-
