@@ -51,9 +51,9 @@ struct mg_request_info {
   } http_headers[64];         // Maximum 64 headers
 };
 
-#if !defined(_WIN32)
+// #if !defined(_WIN32)
 #define USE_IPV6 1
-#endif
+// #endif
 
 // Unified socket address. For IPv6 support, add IPv6 address structure
 // in the union u.
@@ -202,6 +202,8 @@ int mg_printf(struct mg_connection *,
 // Send contents of the entire file together with HTTP headers.
 void mg_send_file(struct mg_connection *conn, const char *path);
 
+// Get the length of the data from the remote end
+int64_t mg_get_content_len(struct mg_connection *conn);
 
 // Read data from the remote end, return number of bytes read.
 int mg_read(struct mg_connection *, void *buf, size_t len);
@@ -278,7 +280,8 @@ void mg_close_connection(struct mg_connection *conn);
 // File upload functionality. Each uploaded file gets saved into a temporary
 // file and MG_UPLOAD event is sent.
 // Return number of uploaded files.
-int mg_upload(struct mg_connection *conn, const char *destination_dir);
+int mg_upload(struct mg_connection *conn, const char *destination_dir,
+	      char *fname, u_int fname_len);
 
 
 // Convenience function -- create detached thread.
